import os
TRAINED_MODEL_DIR = f"trained_models"

DATA_SAVE_DIR = f"datasets"
TRAINED_MODEL_DIR = f"trained_models"
TENSORBOARD_LOG_DIR = f"tensorboard_log"
RESULTS_DIR = f"results"

START_DATE = "2009-01-01"
END_DATE = "2021-01-01"

START_TRADE_DATE = "2019-01-01"

DEFAULT_DATA_COLUMNS = ["date", "tic", "close"]

def setup_dirs():
    os.makedirs("testdata/",exist_ok=True)
    os.makedirs("./testdata/" + DATA_SAVE_DIR,exist_ok=True)
    os.makedirs("./testdata/" + TRAINED_MODEL_DIR,exist_ok=True)
    os.makedirs("./testdata/" + TENSORBOARD_LOG_DIR,exist_ok=True)
    os.makedirs("./testdata/" + RESULTS_DIR,exist_ok=True)

STOCK_INDICATORS_LIST = [
    "macd",
    "boll_ub",
    "boll_lb",
    "rsi_30",
    "dx_30",
    "close_30_sma",
    "close_60_sma",
    "kdjk",
    "open_2_sma",
    "boll",
    "close_10.0_le_5_c",
    "wr_10",
	"dma",
    "trix",
	"vr_6_sma",
	"vr",
	"close_2_tema",
	"tema",
	"trix_9_sma",
	"close_3_trix",
	"adxr",
	"adx",
	"dx",
	"mdi",
	"pdi",
	"atr",
	"tr",
	"cci_20",
	"cci",
	"wr_6",
	"rsi_12",
	"rsi_6",
	"cr-ma2_xu_cr-ma1_20_c",
	"macdh",
	"macds",
	"kdjj",
	"kdjd",
	"volume_-3~1_min",
	"volume_-3,2,-1_max",
	"cr-ma3",
	"cr-ma2",
	"cr-ma1",
	"cr",
	"open_-2_r",
	"open_2_d",
	"volume_delta"
]

ADDITIONAL_STOCK_INDICATORS = [
    # 'vpin_5',
    # 'vpin_22',
    # 'vpin_66',
    # 'vpin_1year',
    # 'vpin_3year',
    # 'vpin_5year',

    'pct_return_5',
    'pct_return_22',
    'pct_return_66',
    'pct_return_1year',
    'pct_return_3year',
    'pct_return_5year',

    'price_diff_5',
    'price_diff_22',
    'price_diff_66',
    'price_diff_1year',
    'price_diff_3year',
    'price_diff_5year',

    'sharpe_diff_5',
    'sharpe_diff_22',
    'sharpe_diff_66',
    'sharpe_diff_1year',
    'sharpe_diff_3year',
    'sharpe_diff_5year',

    'sortino_diff_5',
    'sortino_diff_22',
    'sortino_diff_66',
    'sortino_diff_1year',
    'sortino_diff_3year',
    'sortino_diff_5year',

    'calamar_diff_5',
    'calamar_diff_22',
    'calamar_diff_66',
    'calamar_diff_1year',
    'calamar_diff_3year',
    'calamar_diff_5year',

    'vix_fix_diff_5',
    'vix_fix_diff_22',
    'vix_fix_diff_66',
    'vix_fix_diff_1year',
    'vix_fix_diff_3year',
    'vix_fix_diff_5year',

    'max_value_price_diff_5',
    'max_value_price_diff_22',
    'max_value_price_diff_66',
    'max_value_price_diff_1year',
    'max_value_price_diff_3year',
    'max_value_price_diff_5year',

    'min_value_price_diff_5',
    'min_value_price_diff_22',
    'min_value_price_diff_66',
    'min_value_price_diff_1year',
    'min_value_price_diff_3year',
    'min_value_price_diff_5year',

    'max_value_volume_diff_5',
    'max_value_volume_diff_22',
    'max_value_volume_diff_66',
    'max_value_volume_diff_1year',
    'max_value_volume_diff_3year',
    'max_value_volume_diff_5year',

    'min_value_volume_diff_5',
    'min_value_volume_diff_22',
    'min_value_volume_diff_66',
    'min_value_volume_diff_1year',
    'min_value_volume_diff_3year',
    'min_value_volume_diff_5year',

    'sharpe_5',
    'sharpe_22',
    'sharpe_66',
    'sharpe_1year',
    'sharpe_3year',
    'sharpe_5year',

    'sortino_5',
    'sortino_22',
    'sortino_66',
    'sortino_1year',
    'sortino_3year',
    'sortino_5year',

    'calamar_5',
    'calamar_22',
    'calamar_66',
    'calamar_1year',
    'calamar_3year',
    'calamar_5year',

    'vix_fix_5',
    'vix_fix_22',
    'vix_fix_66',
    'vix_fix_1year',
    'vix_fix_3year',
    'vix_fix_5year',

    'max_value_price_5',
    'max_value_price_22',
    'max_value_price_66',
    'max_value_price_1year',
    'max_value_price_3year',
    'max_value_price_5year',

    'min_value_price_5',
    'min_value_price_22',
    'min_value_price_66',
    'min_value_price_1year',
    'min_value_price_3year',
    'min_value_price_5year',

    'max_value_volume_5',
    'max_value_volume_22',
    'max_value_volume_66',
    'max_value_volume_1year',
    'max_value_volume_3year',
    'max_value_volume_5year',

    'min_value_volume_5',
    'min_value_volume_22',
    'min_value_volume_66',
    'min_value_volume_1year',
    'min_value_volume_3year',
    'min_value_volume_5year',

    'hurst_exp'
]

ADDITIONAL_DAYTRADE_INDICATORS = [
    'half_hour_time',

    'pct_return_10',
    'pct_return_50',
    'pct_return_100',
    'pct_return_500',
    'pct_return_1000',
    
    'price_diff_10',
    'price_diff_50',
    'price_diff_100',
    'price_diff_500',
    'price_diff_1000',

    'sharpe_diff_10',
    'sharpe_diff_50',
    'sharpe_diff_100',
    'sharpe_diff_500',
    'sharpe_diff_1000',

    'sortino_diff_10',
    'sortino_diff_50',
    'sortino_diff_100',
    'sortino_diff_500',
    'sortino_diff_1000',

    'calamar_diff_10',
    'calamar_diff_50',
    'calamar_diff_100',
    'calamar_diff_500',
    'calamar_diff_1000',

    'vix_fix_diff_10',
    'vix_fix_diff_50',
    'vix_fix_diff_100',
    'vix_fix_diff_500',
    'vix_fix_diff_1000',

    'max_value_price_diff_10',
    'max_value_price_diff_50',
    'max_value_price_diff_100',
    'max_value_price_diff_500',
    'max_value_price_diff_1000',

    'min_value_price_diff_10',
    'min_value_price_diff_50',
    'min_value_price_diff_100',
    'min_value_price_diff_500',
    'min_value_price_diff_1000',

    'max_value_volume_diff_10',
    'max_value_volume_diff_50',
    'max_value_volume_diff_100',
    'max_value_volume_diff_500',
    'max_value_volume_diff_1000',

    'min_value_volume_diff_10',
    'min_value_volume_diff_50',
    'min_value_volume_diff_100',
    'min_value_volume_diff_500',
    'min_value_volume_diff_1000',

    
    'sharpe_10',
    'sharpe_50',
    'sharpe_100',
    'sharpe_500',
    'sharpe_1000',

    'sortino_10',
    'sortino_50',
    'sortino_100',
    'sortino_500',
    'sortino_1000',

    'calamar_10',
    'calamar_50',
    'calamar_100',
    'calamar_500',
    'calamar_1000',

    'vix_fix_10',
    'vix_fix_50',
    'vix_fix_100',
    'vix_fix_500',
    'vix_fix_1000',

    # 'vpin_10',
    # 'vpin_50',
    # 'vpin_100',
    # 'vpin_500',
    # 'vpin_1000',

    'max_value_price_10',
    'max_value_price_50',
    'max_value_price_100',
    'max_value_price_500',
    'max_value_price_1000',

    'min_value_price_10',
    'min_value_price_50',
    'min_value_price_100',
    'min_value_price_500',
    'min_value_price_1000',

    'max_value_volume_10',
    'max_value_volume_50',
    'max_value_volume_100',
    'max_value_volume_500',
    'max_value_volume_1000',

    'min_value_volume_10',
    'min_value_volume_50',
    'min_value_volume_100',
    'min_value_volume_500',
    'min_value_volume_1000',
]

ADDITIONAL_DIFF_STOCK_INDICATORS = [
    'sharpe_5',
    'sharpe_22',
    'sharpe_66',
    'sharpe_1year',
    'sharpe_3year',
    'sharpe_5year',

    'sortino_5',
    'sortino_22',
    'sortino_66',
    'sortino_1year',
    'sortino_3year',
    'sortino_5year',

    'calamar_5',
    'calamar_22',
    'calamar_66',
    'calamar_1year',
    'calamar_3year',
    'calamar_5year',

    'vix_fix_5',
    'vix_fix_22',
    'vix_fix_66',
    'vix_fix_1year',
    'vix_fix_3year',
    'vix_fix_5year',

    'max_value_price_5',
    'max_value_price_22',
    'max_value_price_66',
    'max_value_price_1year',
    'max_value_price_3year',
    'max_value_price_5year',

    'min_value_price_5',
    'min_value_price_22',
    'min_value_price_66',
    'min_value_price_1year',
    'min_value_price_3year',
    'min_value_price_5year',

    'max_value_volume_5',
    'max_value_volume_22',
    'max_value_volume_66',
    'max_value_volume_1year',
    'max_value_volume_3year',
    'max_value_volume_5year',

    'min_value_volume_5',
    'min_value_volume_22',
    'min_value_volume_66',
    'min_value_volume_1year',
    'min_value_volume_3year',
    'min_value_volume_5year',

    'hurst_exp'
]

FAANG_TICKER_LIST = ["FB", "AMZN", "AAPL", "NFLX", "GOOG"]

FAANG_TICKER_DICT = {
    "facebook":["FB"],
    "amazon":["AMZN"],
    "apple":["AAPL"],
    "netflix":["NFLX"],
    "google":["GOOG"]
}

## stockstats technical indicator column names
## check https://pypi.org/project/stockstats/ for different names
#TECHNICAL_INDICATORS_LIST = ["macd","boll_ub","boll_lb","rsi_30", "cci_30", "dx_30","close_30_sma","close_60_sma"]
TECHNICAL_INDICATORS_LIST = ["macd","rsi_30", "cci_30", "dx_30"]


## Model Parameters
A2C_PARAMS = {"n_steps": 5, "ent_coef": 0.01, "learning_rate": 0.0007}
PPO_PARAMS = {
    "n_steps": 2048,
    "ent_coef": 0.01,
    "learning_rate": 0.00025,
    "batch_size": 64,
}
DDPG_PARAMS = {"batch_size": 128, "buffer_size": 50000, "learning_rate": 0.001}
TD3_PARAMS = {"batch_size": 100, "buffer_size": 1000000, "learning_rate": 0.001}
SAC_PARAMS = {
    "batch_size": 64,
    "buffer_size": 100000,
    "learning_rate": 0.0001,
    "learning_starts": 100,
    "batch_size": 64,
    "ent_coef": "auto_0.1",
}

########################################################
############## Stock Ticker Setup starts ##############
SINGLE_TICKER = ["AAPL"]

#all stocks
ALL_STOCKS_LIST = [
"A",
"AAL",
"AAOI",
"AAP",
"AAPL",
"AAT",
"AAWW",
"AB",
"ABB",
"ABBV",
"ABC",
"ABCB",
"ABG",
"ABM",
"ABMD",
"ABR",
"ABT",
"ACAD",
"ACB",
"ACC",
"ACCO",
"ACGL",
"ACH",
"ACHC",
"ACIW",
"ACLS",
"ACM",
"ACN",
"ACP",
"ACRE",
"ACRS",
"ACTG",
"ACY",
"ADBE",
"ADC",
"ADI",
"ADM",
"ADP",
"ADS",
"ADSK",
"ADTN",
"ADX",
"AEE",
"AEF",
"AEHR",
"AEIS",
"AEL",
"AEM",
"AEO",
"AEP",
"AER",
"AERI",
"AES",
"AFG",
"AFIN",
"AFL",
"AFMD",
"AG",
"AGCO",
"AGI",
"AGIO",
"AGNC",
"AGO",
"AGR",
"AGRO",
"AHH",
"AHPI",
"AHT",
"AIG",
"AIMC",
"AINV",
"AIR",
"AIV",
"AIZ",
"AJG",
"AJRD",
"AKAM",
"AKR",
"AKTS",
"AL",
"ALB",
"ALE",
"ALEX",
"ALGN",
"ALGT",
"ALK",
"ALKS",
"ALL",
"ALLE",
"ALLY",
"ALNY",
"ALRM",
"ALSN",
"ALT",
"ALV",
"AMAT",
"AMBA",
"AMBC",
"AMBP",
"AMC",
"AMCX",
"AMD",
"AME",
"AMED",
"AMEH",
"AMG",
"AMGN",
"AMH",
"AMKR",
"AMN",
"AMP",
"AMPH",
"AMPL",
"AMRC",
"AMRS",
"AMSC",
"AMT",
"AMTX",
"AMWD",
"AMX",
"AMYT",
"AMZN",
"AN",
"ANET",
"ANF",
"ANGI",
"ANGO",
"ANSS",
"ANTM",
"AOD",
"AON",
"AOS",
"AOSL",
"AOUT",
"APA",
"APAM",
"APD",
"APEN",
"APH",
"APLE",
"APO",
"APOG",
"APPS",
"APT",
"APTS",
"APTV",
"APVO",
"AR",
"ARCB",
"ARCC",
"ARCO",
"ARCT",
"ARDC",
"ARE",
"ARES",
"ARI",
"ARKO",
"ARLP",
"ARMK",
"ARNA",
"AROC",
"ARQQ",
"ARR",
"ARVL",
"ARW",
"ARWR",
"ASB",
"ASG",
"ASGN",
"ASH",
"ASML",
"ASND",
"ASPN",
"ASTL",
"ASUR",
"ATAI",
"ATAX",
"ATCO",
"ATEC",
"ATEN",
"ATGE",
"ATHM",
"ATI",
"ATNM",
"ATO",
"ATR",
"ATRA",
"ATRC",
"ATRO",
"ATSG",
"ATVI",
"AU",
"AUB",
"AUID",
"AUPH",
"AVA",
"AVAV",
"AVB",
"AVD",
"AVDL",
"AVGO",
"AVID",
"AVK",
"AVNS",
"AVNT",
"AVT",
"AVXL",
"AVY",
"AVYA",
"AWF",
"AWK",
"AWP",
"AXDX",
"AXGN",
"AXL",
"AXON",
"AXP",
"AXS",
"AXSM",
"AXTA",
"AXTI",
"AY",
"AYI",
"AZN",
"AZPN",
"AZTA",
"B",
"BA",
"BABA",
"BAC",
"BAH",
"BAK",
"BAM",
"BANC",
"BANF",
"BANR",
"BAP",
"BAX",
"BB",
"BBBY",
"BBDC",
"BBL",
"BBLN",
"BBN",
"BBVA",
"BBW",
"BBWI",
"BBY",
"BC",
"BCC",
"BCE",
"BCH",
"BCO",
"BCOR",
"BCOV",
"BCRX",
"BCS",
"BCTX",
"BCX",
"BDC",
"BDJ",
"BDN",
"BDX",
"BECN",
"BEEM",
"BEN",
"BEP",
"BERY",
"BF/B",
"BFAM",
"BFS",
"BG",
"BGB",
"BGFV",
"BGR",
"BGS",
"BGY",
"BHC",
"BHE",
"BHF",
"BHLB",
"BHP",
"BHR",
"BIDU",
"BIG",
"BIIB",
"BIP",
"BITF",
"BJRI",
"BK",
"BKD",
"BKE",
"BKH",
"BKKT",
"BKNG",
"BKR",
"BKT",
"BKU",
"BLD",
"BLDP",
"BLDR",
"BLFS",
"BLK",
"BLKB",
"BLL",
"BLMN",
"BLNK",
"BLUE",
"BLX",
"BMA",
"BMO",
"BMRN",
"BMY",
"BNED",
"BNFT",
"BNS",
"BOE",
"BOKF",
"BOOM",
"BOOT",
"BOX",
"BOXD",
"BP",
"BPMC",
"BPOP",
"BPYPM",
"BR",
"BRG",
"BRK/B",
"BRKL",
"BRKR",
"BRO",
"BRX",
"BSAC",
"BSBR",
"BSIG",
"BSM",
"BST",
"BSX",
"BTCM",
"BTI",
"BTZ",
"BUD",
"BURL",
"BVN",
"BW",
"BWA",
"BWG",
"BWXT",
"BX",
"BXC",
"BXMT",
"BXMX",
"BXP",
"BYD",
"BYRN",
"BZH",
"BZUN",
"C",
"CACC",
"CADE",
"CAE",
"CAG",
"CAH",
"CAJ",
"CAKE",
"CAL",
"CALM",
"CALX",
"CAMP",
"CAR",
"CARA",
"CASH",
"CASY",
"CAT",
"CATY",
"CB",
"CBOE",
"CBRE",
"CBRL",
"CBSH",
"CBT",
"CBU",
"CC",
"CCAP",
"CCEP",
"CCI",
"CCJ",
"CCK",
"CCL",
"CCMP",
"CCOI",
"CCRN",
"CCS",
"CCSI",
"CCXI",
"CDE",
"CDK",
"CDMO",
"CDNA",
"CDNS",
"CDW",
"CDXS",
"CE",
"CELH",
"CENX",
"CEQP",
"CERN",
"CERS",
"CET",
"CF",
"CFFN",
"CFG",
"CFR",
"CFX",
"CG",
"CGC",
"CGNT",
"CGNX",
"CHD",
"CHEF",
"CHGG",
"CHH",
"CHK",
"CHKP",
"CHMI",
"CHRS",
"CHRW",
"CHS",
"CHTR",
"CHX",
"CI",
"CIB",
"CIEN",
"CIM",
"CINF",
"CIO",
"CIT",
"CL",
"CLAR",
"CLB",
"CLBT",
"CLDT",
"CLDX",
"CLF",
"CLFD",
"CLH",
"CLLS",
"CLM",
"CLNE",
"CLPT",
"CLR",
"CLS",
"CLSK",
"CLX",
"CM",
"CMA",
"CMC",
"CMCSA",
"CME",
"CMG",
"CMI",
"CMP",
"CMRE",
"CMRX",
"CMS",
"CNC",
"CNDT",
"CNHI",
"CNI",
"CNK",
"CNO",
"CNOB",
"CNP",
"CNQ",
"CNR",
"CNSL",
"CNX",
"CNXC",
"CODI",
"COF",
"COHU",
"COIN",
"COLB",
"COLL",
"COLM",
"COMM",
"CONE",
"CONN",
"COO",
"COOP",
"COP",
"CORT",
"COST",
"COTY",
"COWN",
"CP",
"CPA",
"CPB",
"CPE",
"CPG",
"CPRI",
"CPRT",
"CPRX",
"CPSS",
"CPT",
"CQP",
"CR",
"CRDF",
"CRF",
"CRH",
"CRI",
"CRK",
"CRL",
"CRM",
"CRNC",
"CROX",
"CRS",
"CRTO",
"CRUS",
"CRY",
"CS",
"CSCO",
"CSGP",
"CSGS",
"CSII",
"CSIQ",
"CSL",
"CSQ",
"CSTM",
"CSV",
"CSWC",
"CSX",
"CTAS",
"CTLP",
"CTLT",
"CTRA",
"CTRE",
"CTRN",
"CTSH",
"CTT",
"CTXS",
"CUBE",
"CUBI",
"CUK",
"CULP",
"CUTR",
"CUZ",
"CVBF",
"CVE",
"CVET",
"CVGI",
"CVI",
"CVLG",
"CVLT",
"CVM",
"CVS",
"CVT",
"CVX",
"CW",
"CWCO",
"CWEN",
"CWST",
"CWT",
"CX",
"CXW",
"CYBR",
"CYD",
"CYH",
"CYRX",
"CYTK",
"CZOO",
"CZR",
"D",
"DAC",
"DAL",
"DAN",
"DAR",
"DB",
"DBD",
"DBI",
"DBRG",
"DCI",
"DCOM",
"DCP",
"DCTH",
"DDD",
"DDS",
"DE",
"DEA",
"DECK",
"DEI",
"DENN",
"DEO",
"DFS",
"DG",
"DGX",
"DHI",
"DHR",
"DHT",
"DHX",
"DIN",
"DIOD",
"DIS",
"DISCA",
"DISCK",
"DISH",
"DKS",
"DLB",
"DLPN",
"DLR",
"DLTR",
"DLX",
"DNOW",
"DNP",
"DOC",
"DOV",
"DOX",
"DPZ",
"DQ",
"DRD",
"DRE",
"DRH",
"DRI",
"DRQ",
"DSKE",
"DSL",
"DTE",
"DTP",
"DUK",
"DVA",
"DVAX",
"DVN",
"DX",
"DXC",
"DXCM",
"DXLG",
"DXPE",
"DY",
"DZSI",
"E",
"EA",
"EAD",
"EARN",
"EAT",
"EBAY",
"EBS",
"EC",
"ECC           ",
"ECL",
"ECOL",
"ECPG",
"ED",
"EDAP",
"EDD",
"EDF",
"EDSA",
"EEFT",
"EFC",
"EFR",
"EFX",
"EGHT",
"EGLE",
"EGO",
"EGP",
"EHC",
"EHTH",
"EIGR",
"EIX",
"EL",
"ELS",
"ELY",
"EMBK",
"EMD",
"EME",
"EMF",
"EMKR",
"EMN",
"EMR",
"ENB",
"ENIA",
"ENLC",
"ENLV",
"ENOB",
"ENPH",
"ENR",
"ENS",
"ENSG",
"ENTA",
"ENTG",
"ENV",
"ENVA",
"EOD",
"EOG",
"EOSE",
"EPAC",
"EPAM",
"EPAY",
"EPC",
"EPD",
"EPR",
"EQBK",
"EQC",
"EQIX",
"EQNR",
"EQR",
"EQT",
"EQX",
"ERF",
"ERIC",
"ERII",
"ERJ",
"ES",
"ESE",
"ESI",
"ESNT",
"ESRT",
"ESS",
"ESTE",
"ET",
"ETD",
"ETJ",
"ETN",
"ETR",
"ETSY",
"ETV",
"ETW",
"ETY",
"EURN",
"EVC",
"EVGO",
"EVH",
"EVR",
"EVRI",
"EVTC",
"EVV",
"EW",
"EWBC",
"EXAS",
"EXC",
"EXEL",
"EXG",
"EXP",
"EXPD",
"EXPE",
"EXPI",
"EXPO",
"EXR",
"EXTR",
"EYPT",
"EZPW",
"F",
"FAF",
"FANG",
"FANH",
"FARM",
"FAST",
"FATE",
"FB",
"FBC",
"FBHS",
"FBNC",
"FBP",
"FCEL",
"FCF",
"FCFS",
"FCN",
"FCNCA",
"FCPT",
"FCT",
"FCX",
"FDS",
"FDX",
"FE",
"FEI",
"FF",
"FFBC",
"FFC",
"FFIN",
"FFIV",
"FFWM",
"FGEN",
"FHI",
"FHN",
"FIBK",
"FICO",
"FIS",
"FISV",
"FITB",
"FIVE",
"FIVN",
"FIZZ",
"FL",
"FLEX",
"FLL",
"FLO",
"FLOW",
"FLR",
"FLS",
"FLT",
"FLWS",
"FMBI",
"FMC",
"FMS",
"FMX",
"FN",
"FNB",
"FNF",
"FNV",
"FOE",
"FOLD",
"FORM",
"FOSL",
"FOX",
"FOXA",
"FOXF",
"FPF",
"FPI",
"FPL",
"FR",
"FRC",
"FRG",
"FRHC",
"FRME",
"FRO",
"FRPT",
"FRT",
"FSK",
"FSLR",
"FSP",
"FSS",
"FTAI",
"FTDR",
"FTF",
"FTI",
"FTNT",
"FUL",
"FULT",
"FUN",
"FWONK",
"FWRD",
"FYBR",
"G",
"GAB",
"GBCI",
"GBDC",
"GBT",
"GBX",
"GCI",
"GCMG",
"GCO",
"GD",
"GDDY",
"GDOT",
"GE",
"GEF",
"GEL",
"GEO",
"GER",
"GES",
"GF",
"GFF",
"GFI",
"GGAL",
"GGG",
"GHY",
"GIB",
"GIII",
"GIL",
"GILD",
"GILT",
"GIM",
"GIS",
"GKOS",
"GL",
"GLDD",
"GLDI",
"GLNG",
"GLO",
"GLOB",
"GLPG",
"GLPI",
"GLQ",
"GLRE",
"GLW",
"GM",
"GME",
"GMED",
"GNK",
"GNL",
"GNRC",
"GNTX",
"GOF",
"GOGL",
"GOGO",
"GOL",
"GOLD",
"GOOD",
"GOOG",
"GOOGL",
"GP",
"GPC",
"GPI",
"GPK",
"GPN",
"GPRE",
"GPRK",
"GPRO",
"GPS",
"GRAB",
"GREE",
"GRFS",
"GRIN",
"GRMN",
"GRPN",
"GRUB",
"GRWG",
"GS",
"GSBD",
"GSK",
"GSL",
"GSM",
"GT",
"GTLS",
"GTN",
"GTX",
"GTY",
"GVA",
"GWB",
"GWH",
"GWRE",
"GWW",
"H",
"HA",
"HAE",
"HAFC",
"HAIN",
"HAL",
"HALO",
"HAS",
"HASI",
"HBAN",
"HBI",
"HBM",
"HBNC",
"HBP",
"HCA",
"HCI",
"HCSG",
"HD",
"HDB",
"HE",
"HEAR",
"HEI",
"HEP",
"HES",
"HFC",
"HFWA",
"HHC",
"HI",
"HIBB",
"HIG",
"HII",
"HIMX",
"HIO",
"HIW",
"HIX",
"HL",
"HLF",
"HLI",
"HLIT",
"HMC",
"HMHC",
"HMN",
"HMST",
"HNI",
"HOG",
"HOLI",
"HOLX",
"HOMB",
"HON",
"HOPE",
"HP",
"HPE",
"HPP",
"HPQ",
"HQH",
"HQY",
"HR",
"HRB",
"HRL",
"HRTG",
"HRTX",
"HSBC",
"HSC",
"HSIC",
"HSKA",
"HST",
"HSTM",
"HSY",
"HT",
"HTA",
"HTGC",
"HTH",
"HTHT",
"HTLD",
"HTLF",
"HTZ",
"HTZWW",
"HUBB",
"HUBS",
"HUM",
"HUN",
"HUT",
"HVT",
"HWC",
"HWM",
"HXL",
"HYB",
"HYT",
"HZNP",
"HZO",
"IAC",
"IART",
"IBM",
"IBN",
"IBRX",
"ICAD",
"ICE",
"ICL",
"ICLR",
"ICPT",
"ICUI",
"IDA",
"IDXX",
"IEP",
"IEX",
"IFF",
"IGD",
"IGR",
"IGT",
"IHRT",
"III",
"IIVI",
"ILMN",
"IMAX",
"IMBI",
"IMGN",
"IMMR",
"IMO",
"IMTE",
"IMUX",
"INCY",
"INDB",
"INDI",
"INDP",
"INFN",
"INFO",
"INFY",
"ING",
"INGN",
"INGR",
"INN",
"INO",
"INOD",
"INSG",
"INSM",
"INSP",
"INT",
"INTC",
"INTU",
"INVA",
"INVE",
"INVZ",
"IONS",
"IOVA",
"IP",
"IPG",
"IPGP",
"IQV",
"IRBT",
"IRDM",
"IRM",
"IRT",
"IRWD",
"ISBC",
"ISD",
"ISEE",
"ISIG",
"ISRG",
"IT",
"ITCI",
"ITGR",
"ITRI",
"ITT",
"ITW",
"IVZ",
"J",
"JACK",
"JAKK",
"JAZZ",
"JBHT",
"JBL",
"JBLU",
"JCI",
"JD",
"JEF",
"JFR",
"JKHY",
"JKS",
"JLL",
"JNJ",
"JNPR",
"JOBS",
"JPC",
"JPM",
"JPS",
"JQC",
"JRO",
"JRVR",
"JW/A",
"JWN",
"JYNT",
"K",
"KAMN",
"KAR",
"KB",
"KBAL",
"KBH",
"KBR",
"KDNY",
"KDP",
"KELYA",
"KEP",
"KEX",
"KEY",
"KEYS",
"KFY",
"KGC",
"KHC",
"KIM",
"KIND",
"KIRK",
"KKR",
"KL",
"KLAC",
"KLIC",
"KMB",
"KMF",
"KMI",
"KMPH",
"KMPR",
"KMT",
"KMX",
"KN",
"KNOP",
"KO",
"KOSS",
"KPTI",
"KR",
"KRA",
"KRC",
"KRG",
"KRNT",
"KRNY",
"KRO",
"KSS",
"KT",
"KTF",
"KTOS",
"KURA",
"KW",
"KYN",
"L",
"LAC",
"LAD",
"LADR",
"LAMR",
"LAND",
"LAZ",
"LAZY",
"LBRDA",
"LBRDK",
"LBTYA",
"LBTYK",
"LC",
"LCID",
"LDOS",
"LE",
"LEA",
"LECO",
"LEG",
"LEN",
"LEO",
"LEU",
"LFC",
"LGIH",
"LH",
"LHCG",
"LHX",
"LIFE",
"LILA",
"LILAK",
"LILM",
"LIND",
"LITE",
"LIVN",
"LKQ",
"LL",
"LLY",
"LMT",
"LNC",
"LNG",
"LNT",
"LNTH",
"LOB",
"LOCO",
"LOGI",
"LOOP",
"LOPE",
"LOW",
"LPG",
"LPI",
"LPL",
"LPLA",
"LPRO",
"LPSN",
"LPX",
"LQDT",
"LRCX",
"LRN",
"LSCC",
"LSI",
"LSPD",
"LSTR",
"LSXMA",
"LSXMK",
"LTBR",
"LTC",
"LTRX",
"LULU",
"LUMN",
"LUV",
"LVS",
"LWLG",
"LXP",
"LXU",
"LYB",
"LYLT",
"LYV",
"LZB",
"M",
"MA",
"MAA",
"MAC",
"MAG",
"MAIN",
"MAN",
"MANH",
"MANU",
"MAR",
"MARA",
"MAS",
"MASI",
"MAT",
"MATX",
"MAV",
"MAXN",
"MAXR",
"MBI",
"MBOT",
"MBT",
"MC",
"MCD",
"MCFT",
"MCHP",
"MCK",
"MCN",
"MCO",
"MCRB",
"MCS",
"MCY",
"MD",
"MDC",
"MDGL",
"MDIA",
"MDLZ",
"MDRX",
"MDT",
"MDU",
"MDXG",
"ME",
"MEI",
"MELI",
"MEOH",
"MET",
"MFC",
"MFIN",
"MFM",
"MGA",
"MGI",
"MGM",
"MGNI",
"MGNX",
"MGPI",
"MHK",
"MHO",
"MIDD",
"MIGI",
"MIME",
"MITK",
"MITT",
"MKC",
"MKSI",
"MLCO",
"MLI",
"MLKN",
"MLM",
"MMC",
"MMM",
"MMP",
"MMS",
"MMSI",
"MMT",
"MMYT",
"MNDT",
"MNR",
"MNRO",
"MNST",
"MNTX",
"MO",
"MOD",
"MOH",
"MOMO",
"MOS",
"MOV",
"MPC",
"MPLX",
"MPW",
"MPWR",
"MQY",
"MRC",
"MRCY",
"MRK",
"MRO",
"MRTN",
"MRTX",
"MRVL",
"MS",
"MSCI",
"MSEX",
"MSFT",
"MSI",
"MSM",
"MSTR",
"MT",
"MTA",
"MTB",
"MTBC",
"MTCH",
"MTDR",
"MTG",
"MTH",
"MTLS",
"MTN",
"MTOR",
"MTRX",
"MTSI",
"MTW",
"MTZ",
"MU",
"MUFG",
"MUI",
"MULN",
"MUR",
"MUSA",
"MVIS",
"MWA",
"MX",
"MXL",
"MYGN",
"MYI",
"MYMD",
"MYRG",
"NAD",
"NAKD",
"NATI",
"NAVI",
"NBHC",
"NBIX",
"NCLH",
"NCR",
"NCTY",
"NCV",
"NCZ",
"NDAQ",
"NEA",
"NEE",
"NEGG",
"NEM",
"NEO",
"NEOG",
"NEP",
"NEPH",
"NETI",
"NEWR",
"NEWT",
"NFBK",
"NFG",
"NFJ",
"NFLX",
"NG",
"NGG",
"NHI",
"NI",
"NICE",
"NJR",
"NKE",
"NKTR",
"NLOK",
"NLS",
"NLSN",
"NLTX",
"NLY",
"NMFC",
"NMG",
"NMIH",
"NML",
"NMM",
"NMZ",
"NNN",
"NOAH",
"NOC",
"NOG",
"NOK",
"NOV",
"NOW",
"NPTN",
"NQP",
"NRG",
"NRK",
"NRO",
"NRZ",
"NS",
"NSA",
"NSC",
"NSIT",
"NSTG",
"NTAP",
"NTCT",
"NTES",
"NTGR",
"NTP",
"NTRA",
"NTRS",
"NTUS",
"NUAN",
"NUE",
"NURO",
"NUS",
"NUV",
"NUVA",
"NVAX",
"NVCR",
"NVDA",
"NVEI",
"NVG",
"NVO",
"NVRO",
"NVS",
"NVTA",
"NVTS",
"NVTSW",
"NWBI",
"NWE",
"NWG",
"NWL",
"NWS",
"NWSA",
"NX",
"NXDT",
"NXGN",
"NXP",
"NXPI",
"NXRT",
"NXST",
"NYCB",
"NYT",
"NZF",
"O",
"OAS",
"OC",
"OCFC",
"OCSL",
"OCUL",
"ODFL",
"ODP",
"OEC",
"OFC",
"OFG",
"OGE",
"OGS",
"OHI",
"OI",
"OII",
"OKE",
"OLED",
"OLLI",
"OLN",
"OMC",
"OMCL",
"OMER",
"OMF",
"OMI",
"ON",
"ONB",
"ONDS",
"ONTO",
"OPCH",
"OPEN",
"OPI",
"OPRX",
"ORA",
"ORAN",
"ORCL",
"ORI",
"ORLY",
"ORMP",
"OSK",
"OSPN",
"OSTK",
"OSUR",
"OSW",
"OTEX",
"OTRK",
"OUT",
"OVV",
"OXBR",
"OXLC",
"OXY",
"OZ",
"OZK",
"PAA",
"PAAS",
"PACB",
"PACW",
"PAG",
"PAGP",
"PAM",
"PANW",
"PAR",
"PARR",
"PATK",
"PAYA",
"PAYC",
"PAYO",
"PAYX",
"PB",
"PBA",
"PBCT",
"PBF",
"PBH",
"PBI",
"PBR",
"PBT",
"PCAR",
"PCG",
"PCH",
"PCN",
"PCRX",
"PCT",
"PCTY",
"PDCE",
"PDCO",
"PDI",
"PDM",
"PDSB",
"PEAK",
"PEB",
"PEG",
"PEGA",
"PEN",
"PENN",
"PEP",
"PERI",
"PETS",
"PFE",
"PFG",
"PFGC",
"PFL",
"PFLT",
"PFN",
"PFS",
"PFSI",
"PG",
"PGR",
"PGRE",
"PGTI",
"PH",
"PHG",
"PHK",
"PHM",
"PHT",
"PII",
"PINC",
"PKG",
"PKI",
"PKX",
"PLAB",
"PLAY",
"PLCE",
"PLD",
"PLL",
"PLNT",
"PLUG",
"PLXP",
"PLYA",
"PM",
"PMT",
"PNC",
"PNFP",
"PNM",
"PNNT",
"PNR",
"PNTG",
"PNW",
"PODD",
"POLY",
"POOL",
"POR",
"POST",
"POWI",
"POWW",
"PPBI",
"PPC",
"PPG",
"PPL",
"PPSI",
"PRA",
"PRAA",
"PRDO",
"PRFT",
"PRG",
"PRGO",
"PRGS",
"PRIM",
"PRLB",
"PRMW",
"PRO",
"PRPL",
"PRQR",
"PRTA",
"PRTS",
"PRTY",
"PRU",
"PSA",
"PSEC",
"PSO",
"PSTG",
"PSX",
"PSXP",
"PTC",
"PTCT",
"PTEN",
"PTR",
"PTY",
"PUK",
"PVG",
"PVH",
"PWR",
"PXD",
"PYPL",
"PZZA",
"QCOM",
"QDEL",
"QGEN",
"QIWI",
"QLYS",
"QMCO",
"QNST",
"QRTEA",
"QRVO",
"QSR",
"QTWO",
"QUOT",
"QURE",
"R",
"RACE",
"RAD",
"RADA",
"RADI",
"RARE",
"RBA",
"RBBN",
"RC",
"RCEL",
"RCI",
"RCII",
"RCKT",
"RCL",
"RCM",
"RCS",
"RDN",
"RDNT",
"RDS/B",
"RDUS",
"RDWR",
"REE",
"REG",
"REGI",
"REGN",
"REKR",
"RELI",
"RELL",
"RELX",
"RENN",
"REV",
"REXR",
"RF",
"RFIL",
"RFP",
"RGA",
"RGEN",
"RGLD",
"RGNX",
"RH",
"RHI",
"RHP",
"RILY",
"RIO",
"RIOT",
"RIV",
"RJF",
"RL",
"RLGY",
"RLJ",
"RLMD",
"RMBS",
"RMD",
"RMNI",
"RMT",
"RNG",
"RNR",
"RNST",
"RNW",
"ROCC",
"ROG",
"ROIC",
"ROIV",
"ROK",
"ROL",
"ROP",
"ROST",
"RPD",
"RPM",
"RPT",
"RQI",
"RRC",
"RRD",
"RRGB",
"RRX",
"RS",
"RSG",
"RTX",
"RUN",
"RUTH",
"RVNC",
"RVP",
"RVT",
"RWT",
"RY",
"RYAAY",
"RYAM",
"RYN",
"SA",
"SABR",
"SAFM",
"SAGE",
"SAH",
"SAIA",
"SAIC",
"SAM",
"SAND          ",
"SANM",
"SAP",
"SATS",
"SAVA",
"SAVE",
"SBAC",
"SBCF",
"SBGI",
"SBH",
"SBLK",
"SBNY",
"SBOW",
"SBRA",
"SBS",
"SBSW",
"SBUX",
"SCCO",
"SCHN",
"SCHW",
"SCI",
"SCS",
"SCU",
"SCVL",
"SCYX",
"SEAS",
"SEAT",
"SEDG",
"SEE",
"SEIC",
"SEM",
"SF",
"SFL",
"SFM",
"SFNC",
"SGEN",
"SGMA",
"SGML",
"SGMO",
"SGMS",
"SGRY",
"SHAK",
"SHEN",
"SHG",
"SHLX",
"SHO",
"SHOO",
"SHOP",
"SHW",
"SIG",
"SIGA",
"SIGI",
"SIMO",
"SIRI",
"SITC",
"SIVB",
"SIX",
"SJI",
"SJM",
"SJR",
"SJT",
"SKM",
"SKT",
"SKX",
"SKY",
"SKYW",
"SLAB",
"SLB",
"SLCA",
"SLF",
"SLG",
"SLGN",
"SLM",
"SLNH",
"SLP",
"SLRC",
"SLS",
"SLVO",
"SM",
"SMED",
"SMFG",
"SMG",
"SMPL",
"SMRT",
"SMTC",
"SNA",
"SNBR",
"SNN",
"SNP",
"SNPS",
"SNV",
"SNX",
"SNY",
"SO",
"SOFI",
"SOHU",
"SOL",
"SON",
"SONY",
"SPB",
"SPG",
"SPGI",
"SPH",
"SPLK",
"SPNE",
"SPNT",
"SPOK",
"SPR",
"SPTN",
"SPWH",
"SPWR",
"SPXC",
"SQ",
"SQM",
"SR",
"SRC",
"SRCL",
"SRE",
"SRG",
"SRI",
"SRPT",
"SSB",
"SSD",
"SSL",
"SSNC",
"SSP",
"SSRM",
"SSSS",
"SSYS",
"ST",
"STAA",
"STAG",
"STAR          ",
"STC",
"STE",
"STGW",
"STKL",
"STKS",
"STL",
"STLA",
"STLD",
"STM",
"STNG",
"STOR",
"STRA",
"STRC",
"STRL",
"STT",
"STWD",
"STX",
"STXS",
"STZ",
"SU",
"SUI",
"SUM",
"SUN",
"SUPN",
"SVC",
"SWBI",
"SWIR",
"SWK",
"SWKS",
"SWM",
"SWX",
"SXC",
"SYF",
"SYK",
"SYNA",
"SYNH",
"SYY",
"T",
"TAC",
"TACO",
"TAP",
"TARA",
"TBBK",
"TBI",
"TBLA",
"TBPH",
"TCBI",
"TCOM",
"TCPC",
"TCS",
"TD",
"TDC",
"TDF",
"TDG",
"TDOC",
"TDS",
"TEAM",
"TECK",
"TEI",
"TEL",
"TEN",
"TEO",
"TER",
"TEVA",
"TEX",
"TFC",
"TFII",
"TFSL",
"TFX",
"TG",
"TGH",
"TGI",
"TGLS",
"TGNA",
"TGP",
"TGT",
"TGTX",
"THC",
"THO",
"THRM",
"THRX",
"THRY",
"THS",
"THW",
"TILE",
"TJX",
"TKR",
"TLK",
"TLYS",
"TM",
"TMHC",
"TMO",
"TMST",
"TMUS",
"TMX",
"TNDM",
"TNK",
"TNL",
"TNP",
"TOL",
"TPC",
"TPH",
"TPR",
"TPST",
"TPVG",
"TPX",
"TR",
"TREE",
"TREX",
"TRGP",
"TRI",
"TRIP",
"TRMB",
"TRMD",
"TRMK",
"TRN",
"TRNO",
"TROW",
"TROX",
"TRP",
"TRQ",
"TRT",
"TRU",
"TRUP",
"TRV",
"TS",
"TSAT",
"TSCO",
"TSE",
"TSEM",
"TSLA",
"TSLX",
"TSM",
"TSN",
"TSVT",
"TT",
"TTC",
"TTE",
"TTEK",
"TTGT",
"TTM",
"TTMI",
"TTSH",
"TTWO",
"TU",
"TUP",
"TV",
"TVTX",
"TVTY",
"TWI",
"TWNK",
"TWO",
"TWOU",
"TWTR",
"TX",
"TXN",
"TXRH",
"TXT",
"TYL",
"UAA",
"UAL",
"UBS",
"UBSI",
"UCBI",
"UCTT",
"UDR",
"UE",
"UEPS",
"UFPI",
"UGI",
"UGRO",
"UHS",
"UHT",
"UIS",
"UL",
"ULTA",
"UMBF",
"UMC",
"UMH",
"UMPQ",
"UNH",
"UNIT",
"UNM",
"UNP",
"UNVR",
"UPLD",
"UPS",
"URBN",
"URI",
"USA",
"USAC",
"USB",
"USOI",
"UTF",
"UTG",
"UTHR",
"UUUU",
"UVE",
"UVV",
"UWMC",
"V",
"VAC",
"VALE",
"VBTX",
"VC",
"VCEL",
"VCRA",
"VCSA",
"VCYT",
"VECO",
"VEEV",
"VERU",
"VET",
"VFC",
"VFF",
"VG",
"VGI",
"VGR",
"VIAC",
"VIACA",
"VIACP",
"VIAV",
"VICR",
"VIPS",
"VIRT",
"VIVO",
"VLO",
"VLRS",
"VLY",
"VMC",
"VMEO",
"VMO",
"VMW",
"VNDA",
"VNET",
"VNO",
"VNOM",
"VOD",
"VOYA",
"VRA",
"VRAY",
"VRE",
"VREX",
"VRNS",
"VRNT",
"VRSK",
"VRSN",
"VRTX",
"VSAT",
"VSH",
"VST",
"VSTO",
"VTR",
"VTRS",
"VUZI",
"VWE",
"VXRT",
"VZ",
"W",
"WAB",
"WAFD",
"WAL",
"WAT",
"WB",
"WBA",
"WBK",
"WBS",
"WBX",
"WCC",
"WCN",
"WDAY",
"WDC",
"WE",
"WEC",
"WEJO",
"WELL",
"WEN",
"WERN",
"WES",
"WETF",
"WEX",
"WFC",
"WFRD",
"WGO",
"WHR",
"WING",
"WIRE",
"WIT",
"WIX",
"WK",
"WLDN",
"WLK",
"WLKP",
"WLTW",
"WM",
"WMB",
"WMS",
"WMT",
"WNC",
"WOLF",
"WOR",
"WPC",
"WPM",
"WRB",
"WRE",
"WRK",
"WSBC",
"WSC",
"WSFS",
"WSM",
"WSR",
"WST",
"WTFC",
"WTRG",
"WU",
"WW",
"WWD",
"WWE",
"WWW",
"WY",
"WYNN",
"X",
"XAIR",
"XEL",
"XENE",
"XHR",
"XLNX",
"XNCR",
"XOM",
"XPEL",
"XPER",
"XPO",
"XPRO",
"XRAY",
"XRX",
"XYL",
"YELL",
"YELP",
"YNDX",
"YUM",
"YY",
"Z",
"ZBH",
"ZD",
"ZEN",
"ZG",
"ZGNX",
"ZION",
"ZNGA",
"ZTR",
"ZTS",
"ZUMZ",
"ZWS",
"ZYXI",
]

# self defined
SRI_KEHATI_TICKER = [
		"AALI.JK",
		"ADHI.JK",
		"ASII.JK",
		"BBCA.JK", 
		"BBNI.JK",
		"BBRI.JK",
		"BBTN.JK",
		"BMRI.JK",
		"BSDE.JK",
		"INDF.JK",
		"JPFA.JK",
		"JSMR.JK",
		"KLBF.JK",
		"PGAS.JK",
		"PJAA.JK",
		"PPRO.JK",
		"SIDO.JK",
		"SMGR.JK",
		"TINS.JK",
		"TLKM.JK",
		"UNTR.JK",
		"UNVR.JK",
		"WIKA.JK",
		"WSKT.JK",
		"WTON.JK"
]

# check https://wrds-www.wharton.upenn.edu/ for U.S. index constituents
# Dow 30 constituents at 2019/01
DOW_30_TICKER = [
    "AAPL",
    "MSFT",
    "JPM",
    "V",
    "RTX",
    "PG",
    "GS",
    "NKE",
    "DIS",
    "AXP",
    "HD",
    "INTC",
    "WMT",
    "IBM",
    "MRK",
    "UNH",
    "KO",
    "CAT",
    "TRV",
    "JNJ",
    "CVX",
    "MCD",
    "VZ",
    "CSCO",
    "XOM",
    "BA",
    "MMM",
    "PFE",
    "WBA",
    "DD",
]

# Nasdaq 100 constituents at 2019/01
NAS_100_TICKER = [
    "AMGN",
    "AAPL",
    "AMAT",
    "INTC",
    "PCAR",
    "PAYX",
    "MSFT",
    "ADBE",
    "CSCO",
    "XLNX",
    "QCOM",
    "COST",
    "SBUX",
    "FISV",
    "CTXS",
    "INTU",
    "AMZN",
    "EBAY",
    "BIIB",
    "CHKP",
    "GILD",
    "NLOK",
    "CMCSA",
    "FAST",
    "ADSK",
    "CTSH",
    "NVDA",
    "GOOGL",
    "ISRG",
    "VRTX",
    "HSIC",
    "BIDU",
    "ATVI",
    "ADP",
    "ROST",
    "ORLY",
    "CERN",
    "BKNG",
    "MYL",
    "MU",
    "DLTR",
    "ALXN",
    "SIRI",
    "MNST",
    "AVGO",
    "TXN",
    "MDLZ",
    "FB",
    "ADI",
    "WDC",
    "REGN",
    "LBTYK",
    "VRSK",
    "NFLX",
    "TSLA",
    "CHTR",
    "MAR",
    "ILMN",
    "LRCX",
    "EA",
    "AAL",
    "WBA",
    "KHC",
    "BMRN",
    "JD",
    "SWKS",
    "INCY",
    "PYPL",
    "CDW",
    "FOXA",
    "MXIM",
    "TMUS",
    "EXPE",
    "TCOM",
    "ULTA",
    "CSX",
    "NTES",
    "MCHP",
    "CTAS",
    "KLAC",
    "HAS",
    "JBHT",
    "IDXX",
    "WYNN",
    "MELI",
    "ALGN",
    "CDNS",
    "WDAY",
    "SNPS",
    "ASML",
    "TTWO",
    "PEP",
    "NXPI",
    "XEL",
    "AMD",
    "NTAP",
    "VRSN",
    "LULU",
    "WLTW",
    "UAL",
]

# SP 500 constituents at 2019
SP_500_TICKER = [
    "A",
    "AAL",
    "AAP",
    "AAPL",
    "ABBV",
    "ABC",
    "ABMD",
    "ABT",
    "ACN",
    "ADBE",
    "ADI",
    "ADM",
    "ADP",
    "ADS",
    "ADSK",
    "AEE",
    "AEP",
    "AES",
    "AFL",
    "AGN",
    "AIG",
    "AIV",
    "AIZ",
    "AJG",
    "AKAM",
    "ALB",
    "ALGN",
    "ALK",
    "ALL",
    "ALLE",
    "ALXN",
    "AMAT",
    "AMCR",
    "AMD",
    "AME",
    "AMG",
    "AMGN",
    "AMP",
    "AMT",
    "AMZN",
    "ANET",
    "ANSS",
    "ANTM",
    "AON",
    "AOS",
    "APA",
    "APD",
    "APH",
    "APTV",
    "ARE",
    "ARNC",
    "ATO",
    "ATVI",
    "AVB",
    "AVGO",
    "AVY",
    "AWK",
    "AXP",
    "AZO",
    "BA",
    "BAC",
    "BAX",
    "BBT",
    "BBY",
    "BDX",
    "BEN",
    "BF.B",
    "BHGE",
    "BIIB",
    "BK",
    "BKNG",
    "BLK",
    "BLL",
    "BMY",
    "BR",
    "BRK.B",
    "BSX",
    "BWA",
    "BXP",
    "C",
    "CAG",
    "CAH",
    "CAT",
    "CB",
    "CBOE",
    "CBRE",
    "CBS",
    "CCI",
    "CCL",
    "CDNS",
    "CE",
    "CELG",
    "CERN",
    "CF",
    "CFG",
    "CHD",
    "CHRW",
    "CHTR",
    "CI",
    "CINF",
    "CL",
    "CLX",
    "CMA",
    "CMCSA",
    "CME",
    "CMG",
    "CMI",
    "CMS",
    "CNC",
    "CNP",
    "COF",
    "COG",
    "COO",
    "COP",
    "COST",
    "COTY",
    "CPB",
    "CPRI",
    "CPRT",
    "CRM",
    "CSCO",
    "CSX",
    "CTAS",
    "CTL",
    "CTSH",
    "CTVA",
    "CTXS",
    "CVS",
    "CVX",
    "CXO",
    "D",
    "DAL",
    "DD",
    "DE",
    "DFS",
    "DG",
    "DGX",
    "DHI",
    "DHR",
    "DIS",
    "DISCK",
    "DISH",
    "DLR",
    "DLTR",
    "DOV",
    "DOW",
    "DRE",
    "DRI",
    "DTE",
    "DUK",
    "DVA",
    "DVN",
    "DXC",
    "EA",
    "EBAY",
    "ECL",
    "ED",
    "EFX",
    "EIX",
    "EL",
    "EMN",
    "EMR",
    "EOG",
    "EQIX",
    "EQR",
    "ES",
    "ESS",
    "ETFC",
    "ETN",
    "ETR",
    "EVRG",
    "EW",
    "EXC",
    "EXPD",
    "EXPE",
    "EXR",
    "F",
    "FANG",
    "FAST",
    "FB",
    "FBHS",
    "FCX",
    "FDX",
    "FE",
    "FFIV",
    "FIS",
    "FISV",
    "FITB",
    "FLIR",
    "FLS",
    "FLT",
    "FMC",
    "FOXA",
    "FRC",
    "FRT",
    "FTI",
    "FTNT",
    "FTV",
    "GD",
    "GE",
    "GILD",
    "GIS",
    "GL",
    "GLW",
    "GM",
    "GOOG",
    "GPC",
    "GPN",
    "GPS",
    "GRMN",
    "GS",
    "GWW",
    "HAL",
    "HAS",
    "HBAN",
    "HBI",
    "HCA",
    "HCP",
    "HD",
    "HES",
    "HFC",
    "HIG",
    "HII",
    "HLT",
    "HOG",
    "HOLX",
    "HON",
    "HP",
    "HPE",
    "HPQ",
    "HRB",
    "HRL",
    "HSIC",
    "HST",
    "HSY",
    "HUM",
    "IBM",
    "ICE",
    "IDXX",
    "IEX",
    "IFF",
    "ILMN",
    "INCY",
    "INFO",
    "INTC",
    "INTU",
    "IP",
    "IPG",
    "IPGP",
    "IQV",
    "IR",
    "IRM",
    "ISRG",
    "IT",
    "ITW",
    "IVZ",
    "JBHT",
    "JCI",
    "JEC",
    "JEF",
    "JKHY",
    "JNJ",
    "JNPR",
    "JPM",
    "JWN",
    "K",
    "KEY",
    "KEYS",
    "KHC",
    "KIM",
    "KLAC",
    "KMB",
    "KMI",
    "KMX",
    "KO",
    "KR",
    "KSS",
    "KSU",
    "L",
    "LB",
    "LDOS",
    "LEG",
    "LEN",
    "LH",
    "LHX",
    "LIN",
    "LKQ",
    "LLY",
    "LMT",
    "LNC",
    "LNT",
    "LOW",
    "LRCX",
    "LUV",
    "LW",
    "LYB",
    "M",
    "MA",
    "MAA",
    "MAC",
    "MAR",
    "MAS",
    "MCD",
    "MCHP",
    "MCK",
    "MCO",
    "MDLZ",
    "MDT",
    "MET",
    "MGM",
    "MHK",
    "MKC",
    "MKTX",
    "MLM",
    "MMC",
    "MMM",
    "MNST",
    "MO",
    "MOS",
    "MPC",
    "MRK",
    "MRO",
    "MS",
    "MSCI",
    "MSFT",
    "MSI",
    "MTB",
    "MTD",
    "MU",
    "MXIM",
    "MYL",
    "NBL",
    "NCLH",
    "NDAQ",
    "NEE",
    "NEM",
    "NFLX",
    "NI",
    "NKE",
    "NKTR",
    "NLSN",
    "NOC",
    "NOV",
    "NRG",
    "NSC",
    "NTAP",
    "NTRS",
    "NUE",
    "NVDA",
    "NWL",
    "NWS",
    "O",
    "OI",
    "OKE",
    "OMC",
    "ORCL",
    "ORLY",
    "OXY",
    "PAYX",
    "PBCT",
    "PCAR",
    "PEG",
    "PEP",
    "PFE",
    "PFG",
    "PG",
    "PGR",
    "PH",
    "PHM",
    "PKG",
    "PKI",
    "PLD",
    "PM",
    "PNC",
    "PNR",
    "PNW",
    "PPG",
    "PPL",
    "PRGO",
    "PRU",
    "PSA",
    "PSX",
    "PVH",
    "PWR",
    "PXD",
    "PYPL",
    "QCOM",
    "QRVO",
    "RCL",
    "RE",
    "REG",
    "REGN",
    "RF",
    "RHI",
    "RJF",
    "RL",
    "RMD",
    "ROK",
    "ROL",
    "ROP",
    "ROST",
    "RSG",
    "RTN",
    "SBAC",
    "SBUX",
    "SCHW",
    "SEE",
    "SHW",
    "SIVB",
    "SJM",
    "SLB",
    "SLG",
    "SNA",
    "SNPS",
    "SO",
    "SPG",
    "SPGI",
    "SRE",
    "STI",
    "STT",
    "STX",
    "STZ",
    "SWK",
    "SWKS",
    "SYF",
    "SYK",
    "SYMC",
    "SYY",
    "T",
    "TAP",
    "TDG",
    "TEL",
    "TFX",
    "TGT",
    "TIF",
    "TJX",
    "TMO",
    "TMUS",
    "TPR",
    "TRIP",
    "TROW",
    "TRV",
    "TSCO",
    "TSN",
    "TSS",
    "TTWO",
    "TWTR",
    "TXN",
    "TXT",
    "UA",
    "UAL",
    "UDR",
    "UHS",
    "ULTA",
    "UNH",
    "UNM",
    "UNP",
    "UPS",
    "URI",
    "USB",
    "UTX",
    "V",
    "VAR",
    "VFC",
    "VIAB",
    "VLO",
    "VMC",
    "VNO",
    "VRSK",
    "VRSN",
    "VRTX",
    "VTR",
    "VZ",
    "WAB",
    "WAT",
    "WBA",
    "WCG",
    "WDC",
    "WEC",
    "WELL",
    "WFC",
    "WHR",
    "WLTW",
    "WM",
    "WMB",
    "WMT",
    "WRK",
    "WU",
    "WY",
    "WYNN",
    "XEC",
    "XEL",
    "XLNX",
    "XOM",
    "XRAY",
    "XRX",
    "XYL",
    "YUM",
    "ZBH",
    "ZION",
    "ZTS",
]

# Hang Seng Index constituents at 2019/01
HSI_50_TICKER = [
    "0011.HK",
    "0005.HK",
    "0012.HK",
    "0006.HK",
    "0003.HK",
    "0016.HK",
    "0019.HK",
    "0002.HK",
    "0001.HK",
    "0267.HK",
    "0101.HK",
    "0941.HK",
    "0762.HK",
    "0066.HK",
    "0883.HK",
    "2388.HK",
    "0017.HK",
    "0083.HK",
    "0939.HK",
    "0388.HK",
    "0386.HK",
    "3988.HK",
    "2628.HK",
    "1398.HK",
    "2318.HK",
    "3328.HK",
    "0688.HK",
    "0857.HK",
    "1088.HK",
    "0700.HK",
    "0836.HK",
    "1109.HK",
    "1044.HK",
    "1299.HK",
    "0151.HK",
    "1928.HK",
    "0027.HK",
    "2319.HK",
    "0823.HK",
    "1113.HK",
    "1038.HK",
    "2018.HK",
    "0175.HK",
    "0288.HK",
    "1997.HK",
    "2007.HK",
    "2382.HK",
    "1093.HK",
    "1177.HK",
    "2313.HK",
]

# www.csindex.com.cn, for SSE and CSI adjustments
# SSE 50 Index constituents at 2019
SSE_50_TICKER = [
    "600000.SS",
    "600036.SS",
    "600104.SS",
    "600030.SS",
    "601628.SS",
    "601166.SS",
    "601318.SS",
    "601328.SS",
    "601088.SS",
    "601857.SS",
    "601601.SS",
    "601668.SS",
    "601288.SS",
    "601818.SS",
    "601989.SS",
    "601398.SS",
    "600048.SS",
    "600028.SS",
    "600050.SS",
    "600519.SS",
    "600016.SS",
    "600887.SS",
    "601688.SS",
    "601186.SS",
    "601988.SS",
    "601211.SS",
    "601336.SS",
    "600309.SS",
    "603993.SS",
    "600690.SS",
    "600276.SS",
    "600703.SS",
    "600585.SS",
    "603259.SS",
    "601888.SS",
    "601138.SS",
    "600196.SS",
    "601766.SS",
    "600340.SS",
    "601390.SS",
    "601939.SS",
    "601111.SS",
    "600029.SS",
    "600019.SS",
    "601229.SS",
    "601800.SS",
    "600547.SS",
    "601006.SS",
    "601360.SS",
    "600606.SS",
    "601319.SS",
    "600837.SS",
    "600031.SS",
    "601066.SS",
    "600009.SS",
    "601236.SS",
    "601012.SS",
    "600745.SS",
    "600588.SS",
    "601658.SS",
    "601816.SS",
    "603160.SS",
]

# CSI 300 Index constituents at 2019
CSI_300_TICKER = [
    "600000.SS",
    "600004.SS",
    "600009.SS",
    "600010.SS",
    "600011.SS",
    "600015.SS",
    "600016.SS",
    "600018.SS",
    "600019.SS",
    "600025.SS",
    "600027.SS",
    "600028.SS",
    "600029.SS",
    "600030.SS",
    "600031.SS",
    "600036.SS",
    "600038.SS",
    "600048.SS",
    "600050.SS",
    "600061.SS",
    "600066.SS",
    "600068.SS",
    "600085.SS",
    "600089.SS",
    "600104.SS",
    "600109.SS",
    "600111.SS",
    "600115.SS",
    "600118.SS",
    "600170.SS",
    "600176.SS",
    "600177.SS",
    "600183.SS",
    "600188.SS",
    "600196.SS",
    "600208.SS",
    "600219.SS",
    "600221.SS",
    "600233.SS",
    "600271.SS",
    "600276.SS",
    "600297.SS",
    "600299.SS",
    "600309.SS",
    "600332.SS",
    "600340.SS",
    "600346.SS",
    "600352.SS",
    "600362.SS",
    "600369.SS",
    "600372.SS",
    "600383.SS",
    "600390.SS",
    "600398.SS",
    "600406.SS",
    "600436.SS",
    "600438.SS",
    "600482.SS",
    "600487.SS",
    "600489.SS",
    "600498.SS",
    "600516.SS",
    "600519.SS",
    "600522.SS",
    "600547.SS",
    "600570.SS",
    "600583.SS",
    "600585.SS",
    "600588.SS",
    "600606.SS",
    "600637.SS",
    "600655.SS",
    "600660.SS",
    "600674.SS",
    "600690.SS",
    "600703.SS",
    "600705.SS",
    "600741.SS",
    "600745.SS",
    "600760.SS",
    "600795.SS",
    "600809.SS",
    "600837.SS",
    "600848.SS",
    "600867.SS",
    "600886.SS",
    "600887.SS",
    "600893.SS",
    "600900.SS",
    "600919.SS",
    "600926.SS",
    "600928.SS",
    "600958.SS",
    "600968.SS",
    "600977.SS",
    "600989.SS",
    "600998.SS",
    "600999.SS",
    "601006.SS",
    "601009.SS",
    "601012.SS",
    "601018.SS",
    "601021.SS",
    "601066.SS",
    "601077.SS",
    "601088.SS",
    "601100.SS",
    "601108.SS",
    "601111.SS",
    "601117.SS",
    "601138.SS",
    "601155.SS",
    "601162.SS",
    "601166.SS",
    "601169.SS",
    "601186.SS",
    "601198.SS",
    "601211.SS",
    "601212.SS",
    "601216.SS",
    "601225.SS",
    "601229.SS",
    "601231.SS",
    "601236.SS",
    "601238.SS",
    "601288.SS",
    "601298.SS",
    "601318.SS",
    "601319.SS",
    "601328.SS",
    "601336.SS",
    "601360.SS",
    "601377.SS",
    "601390.SS",
    "601398.SS",
    "601555.SS",
    "601577.SS",
    "601600.SS",
    "601601.SS",
    "601607.SS",
    "601618.SS",
    "601628.SS",
    "601633.SS",
    "601658.SS",
    "601668.SS",
    "601669.SS",
    "601688.SS",
    "601698.SS",
    "601727.SS",
    "601766.SS",
    "601788.SS",
    "601800.SS",
    "601808.SS",
    "601816.SS",
    "601818.SS",
    "601828.SS",
    "601838.SS",
    "601857.SS",
    "601877.SS",
    "601878.SS",
    "601881.SS",
    "601888.SS",
    "601898.SS",
    "601899.SS",
    "601901.SS",
    "601916.SS",
    "601919.SS",
    "601933.SS",
    "601939.SS",
    "601985.SS",
    "601988.SS",
    "601989.SS",
    "601992.SS",
    "601997.SS",
    "601998.SS",
    "603019.SS",
    "603156.SS",
    "603160.SS",
    "603259.SS",
    "603260.SS",
    "603288.SS",
    "603369.SS",
    "603501.SS",
    "603658.SS",
    "603799.SS",
    "603833.SS",
    "603899.SS",
    "603986.SS",
    "603993.SS",
    "000001.SZ",
    "000002.SZ",
    "000063.SZ",
    "000066.SZ",
    "000069.SZ",
    "000100.SZ",
    "000157.SZ",
    "000166.SZ",
    "000333.SZ",
    "000338.SZ",
    "000425.SZ",
    "000538.SZ",
    "000568.SZ",
    "000596.SZ",
    "000625.SZ",
    "000627.SZ",
    "000651.SZ",
    "000656.SZ",
    "000661.SZ",
    "000671.SZ",
    "000703.SZ",
    "000708.SZ",
    "000709.SZ",
    "000723.SZ",
    "000725.SZ",
    "000728.SZ",
    "000768.SZ",
    "000776.SZ",
    "000783.SZ",
    "000786.SZ",
    "000858.SZ",
    "000860.SZ",
    "000876.SZ",
    "000895.SZ",
    "000938.SZ",
    "000961.SZ",
    "000963.SZ",
    "000977.SZ",
    "001979.SZ",
    "002001.SZ",
    "002007.SZ",
    "002008.SZ",
    "002024.SZ",
    "002027.SZ",
    "002032.SZ",
    "002044.SZ",
    "002050.SZ",
    "002120.SZ",
    "002129.SZ",
    "002142.SZ",
    "002146.SZ",
    "002153.SZ",
    "002157.SZ",
    "002179.SZ",
    "002202.SZ",
    "002230.SZ",
    "002236.SZ",
    "002241.SZ",
    "002252.SZ",
    "002271.SZ",
    "002304.SZ",
    "002311.SZ",
    "002352.SZ",
    "002371.SZ",
    "002410.SZ",
    "002415.SZ",
    "002422.SZ",
    "002456.SZ",
    "002460.SZ",
    "002463.SZ",
    "002466.SZ",
    "002468.SZ",
    "002475.SZ",
    "002493.SZ",
    "002508.SZ",
    "002555.SZ",
    "002558.SZ",
    "002594.SZ",
    "002601.SZ",
    "002602.SZ",
    "002607.SZ",
    "002624.SZ",
    "002673.SZ",
    "002714.SZ",
    "002736.SZ",
    "002739.SZ",
    "002773.SZ",
    "002841.SZ",
    "002916.SZ",
    "002938.SZ",
    "002939.SZ",
    "002945.SZ",
    "002958.SZ",
    "003816.SZ",
    "300003.SZ",
    "300014.SZ",
    "300015.SZ",
    "300033.SZ",
    "300059.SZ",
    "300122.SZ",
    "300124.SZ",
    "300136.SZ",
    "300142.SZ",
    "300144.SZ",
    "300347.SZ",
    "300408.SZ",
    "300413.SZ",
    "300433.SZ",
    "300498.SZ",
    "300601.SZ",
    "300628.SZ",
]

# Check https://www.bnains.org/archives/histocac/compocac.php for CAC 40 constituents
# CAC 40 constituents at 2019/01
CAC_40_TICKER = [
    "AC.PA",
    "AI.PA",
    "AIR.PA",
    "MT.AS",
    "ATO.PA",
    "CS.PA",
    "BNP.PA",
    "EN.PA",
    "CAP.PA",
    "CA.PA",
    "ACA.PA",
    "BN.PA",
    "DSY.PA",
    "ENGI.PA",
    "EL.PA",
    "RMS.PA",
    "KER.PA",
    "OR.PA",
    "LR.PA",
    "MC.PA",
    "ML.PA",
    "ORA.PA",
    "RI.PA",
    "PUGOY",
    "PUB.PA",
    "RNO.PA",
    "SAF.PA",
    "SGO.PA",
    "SAN.PA",
    "SU.PA",
    "GLE.PA",
    "SW.PA",
    "STM.PA",
    "FTI.PA",
    "FP.PA",
    "URW.AS",
    "FR.PA",
    "VIE.PA",
    "DG.PA",
    "VIV.PA",
]

# DAX 30 constituents at 2021/02
DAX_30_TICKER = [
	"DHER.DE", 
	"RWE.DE", 
	"FRE.DE",
	"MTX.DE",
	"MRK.DE", 
	"LIN.DE", 
	"ALV.DE", 
	"VNA.DE", 
	"EOAN.DE", 
	"HEN3.DE", 
	"DAI.DE", 
	"DB1.DE", 
	"DPW.DE", 
	"DWNI.DE", 
	"BMW.DE", 
	"DTE.DE", 
	"VOW3.DE", 
	"MUV2.DE", 
	"1COV.DE", 
	"SAP.DE", 
	"FME.DE", 
	"BAS.DE", 
	"BAYN.DE", 
	"BEI.DE", 
	"CON.DE", 
	"SIE.DE", 
	"ADS.DE", 
	"HEI.DE", 
	"DBK.DE", 
	"IFX.DE"
]

# TecDAX constituents at 2021/02
TECDAX_TICKER = [
	'ADV.DE',
	'AFX.DE',
	'AM3D.DE',
	'BC8.DE',
	'COK.DE',
	'DLG.DE',
	'DRI.DE',
	'DRW3.DE',
	'EVT.DE',
	'FNTN.DE',
	'GFT.DE',
	'JEN.DE',
	'MDG1.DE',
	'MOR.DE',
	'NDX1.DE',
	'NEM.DE',
	'O2D.DE',
	'PFV.DE',
	'QIA.DE',
	'RIB.DE',
	'S92.DE',
	'SANT.DE',
	'SOW.DE',
	'SRT3.DE',
	'UTDI.DE',
	'WAF.DE',
	'WDI.DE'
]

# MDAX 50 constituents at 2021/02
MDAX_50_TICKER = [
	'1COV.DE',
	 'AIR.DE',
	 'AOX.DE',
	 'ARL.DE',
	 'BNR.DE',
	 'BOSS.DE',
	 'DEQ.DE',
	 'DUE.DE',
	 'DWNI.DE',
	 'EVD.DE',
	 'EVK.DE',
	 'FIE.DE',
	 'FPE3.DE',
	 'FRA.DE',
	 'G1A.DE',
	 'GBF.DE',
	 'GXI.DE',
	 'HLE.DE',
	 'HNR1.DE',
	 'HOT.DE',
	 'JUN3.DE',
	 'KGX.DE',
	 'KRN.DE',
	 'LEG.DE',
	 'LEO.DE',
	 'LXS.DE',
	 'MTX.DE',
	 'NDA.DE',
	 'NOEJ.DE',
	 'OSR.DE',
	 'PBB.DE',
	 'RAA.DE',
	 'RHM.DE',
	 'RRTL.DE',
	 'SAX.DE',
	 'SDF.DE',
	 'SHA.DE',
	 'SNH.DE',
	 'SY1.DE',
	 'SZG.DE',
	 'SZU.DE',
	 'TEG.DE',
	 'TLX.DE',
	 'UN01.DE',
	 'WCH.DE',
	 'ZAL.DE'
]

# SDAX 50 constituents at 2021/02
SDAX_50_TICKER = [
	'AAD.DE',
	 'ACX.DE',
	 'ADJ.DE',
	 'ADL.DE',
	 'BDT.DE',
	 'BIO3.DE',
	 'BVB.DE',
	 'BYW6.DE',
	 'CWC.DE',
	 'DBAN.DE',
	 'DEZ.DE',
	 'DIC.DE',
	 'G24.DE',
	 'GIL.DE',
	 'GLJ.DE',
	 'GMM.DE',
	 'HBH.DE',
	 'HDD.DE',
	 'HHFA.DE',
	 'HLAG.DE',
	 'HYQ.DE',
	 'INH.DE',
	 'KCO.DE',
	 'KWS.DE',
	 'PUM.DE',
	 'RHK.DE',
	 'SFQ.DE',
	 'SGL.DE',
	 'SIX2.DE',
	 'SKB.DE',
	 'STM.DE',
	 'TC1.DE',
	 'TLG.DE',
	 'TTK.DE',
	 'VOS.DE',
	 'WAC.DE',
	 'WCMK.DE',
	 'WSU.DE',
	 'WUW.DE',
	 'ZIL2.DE',
	 'ZO1.DE'
]

############## Stock Ticker Setup ends ##############

###Jan 20,2020, added by YuQing Huang###################
################FX Ticker Setup Start###################
FX_TICKER = ["AUDCAD=X",
            "AUDCHF=X",
            "AUDJPY=X",
            "AUDNZD=X",
            "AUDSGD=X",
            "AUDUSD=X",
            "CADCHF=X",
            "CADHKD=X",
            "CADJPY=X",
            "CHFJPY=X",
            "CHFSGD=X",
            "EURAUD=X",
            "EURCAD=X",
            "EURCHF=X",
            "EURCHF=X",
            "EURCHF=X",
            "EURCZK=X",
            "EURGBP=X",
            "EURHKD=X",
            "EURHUF=X",
            "EURJPY=X",
            "EURNOK=X",
            "EURNZD=X",
            "EURPLN=X",
            "EURRUB=X",
            "EURSEK=X",
            "EURSGD=X",
            "EURTRY=X",
            "EURTRY=X",
            "EURUSD=X",
            "GBPAUD=X",
            "GBPAUD=X",
            "GBPAUD=X",
            "GBPCAD=X",
            "GBPCHF=X",
            "GBPJPY=X",
            "GBPNZD=X",
            "GBPUSD=X",
            "HKDJPY=X",
            "NZDCAD=X",
            "NZDCHF=X",
            "NZDJPY=X",
            "NZDUSD=X",
            "SGDJPY=X",
            "TRYJPY=X",
            "USDCAD=X",
            "USDCHF=X",
            "USDCNH=X",
            "USDCZK=X",
            "USDHKD=X",
            "USDHUF=X",
            "USDILS=X",
            "USDJPY=X",
            "USDMXN=X",
            "USDNOK=X",
            "USDPLN=X",
            "USDRON=X",
            "USDRUB=X",
            "USDSEK=X",
            "USDSGD=X",
            "USDTHB=X",
            "USDTRY=X",
            "USDZAR=X",
            "XAGUSD=X",
            "XAUUSD=X",
            "ZARJPY=X",
            "EURDKK=X"
]
################FX Ticker Setup End###################

ALL_STOCKS = [
	"A",
"AA",
"AAC",
"AACG",
"AACIU",
"AADI",
"AAIC",
"AAIN",
"AAL",
"AAMC",
"AAME",
"AAN",
"AAOI",
"AAON",
"AAP",
"AAPL",
"AAQC",
"AAT",
"AATC",
"AAU",
"AAWW",
"AB",
"ABB",
"ABBV",
"ABC",
"ABCB",
"ABCL",
"ABCM",
"ABEO",
"ABEV",
"ABG",
"ABGI",
"ABIO",
"ABM",
"ABMD",
"ABNB",
"ABOS",
"ABR",
"ABSI",
"ABST",
"ABT",
"ABTX",
"ABUS",
"ABVC",
"AC",
"ACA",
"ACAD",
"ACAH",
"ACAHU",
"ACAHW",
"ACB",
"ACBA",
"ACBAW",
"ACBI",
"ACC",
"ACCD",
"ACCO",
"ACEL",
"ACER",
"ACET",
"ACEV",
"ACEVU",
"ACEVW",
"ACGL",
"ACGLN",
"ACGLO",
"ACH",
"ACHC",
"ACHL",
"ACHR",
"ACHV",
"ACI",
"ACII",
"ACIU",
"ACIW",
"ACKIU",
"ACKIW",
"ACLS",
"ACM",
"ACMR",
"ACN",
"ACNB",
"ACOR",
"ACP",
"ACQR",
"ACQRU",
"ACQRW",
"ACR",
"ACRE",
"ACRO",
"ACRS",
"ACRX",
"ACST",
"ACT",
"ACTD",
"ACTDW",
"ACTG",
"ACU",
"ACV",
"ACVA",
"ACXP",
"ACY",
"ADAG",
"ADALU",
"ADAP",
"ADBE",
"ADC",
"ADCT",
"ADER",
"ADERU",
"ADERW",
"ADES",
"ADEX",
"ADF",
"ADGI",
"ADI",
"ADIL",
"ADILW",
"ADM",
"ADMA",
"ADMP",
"ADMS",
"ADN",
"ADNT",
"ADNWW",
"ADOC",
"ADOCR",
"ADOCW",
"ADP",
"ADPT",
"ADRA",
"ADS",
"ADSK",
"ADT",
"ADTN",
"ADTX",
"ADUS",
"ADV",
"ADVM",
"ADVWW",
"ADX",
"ADXN",
"ADXS",
"AE",
"AEAC",
"AEACU",
"AEACW",
"AEAEU",
"AEE",
"AEF",
"AEFC",
"AEG",
"AEHAU",
"AEHAW",
"AEHL",
"AEHR",
"AEI",
"AEIS",
"AEL",
"AEM",
"AEMD",
"AENZ",
"AEO",
"AEP",
"AEPPL",
"AEPPZ",
"AER",
"AERI",
"AES",
"AESC",
"AESE",
"AEVA",
"AEY",
"AEYE",
"AEZS",
"AFAQ",
"AFAQU",
"AFAQW",
"AFB",
"AFBI",
"AFCG",
"AFG",
"AFGB",
"AFGC",
"AFGD",
"AFGE",
"AFI",
"AFIB",
"AFIN",
"AFINO",
"AFINP",
"AFL",
"AFMD",
"AFRM",
"AFT",
"AFTR",
"AFYA",
"AG",
"AGAC",
"AGBA",
"AGBAR",
"AGBAU",
"AGBAW",
"AGC",
"AGCB",
"AGCO",
"AGCUU",
"AGCWW",
"AGD",
"AGE",
"AGEN",
"AGFS",
"AGFY",
"AGGR",
"AGGRU",
"AGGRW",
"AGI",
"AGIL",
"AGILW",
"AGIO",
"AGL",
"AGLE",
"AGM",
"AGMH",
"AGNC",
"AGNCM",
"AGNCN",
"AGNCO",
"AGNCP",
"AGO",
"AGR",
"AGRI",
"AGRIW",
"AGRO",
"AGRX",
"AGS",
"AGTC",
"AGTI",
"AGX",
"AGYS",
"AHCO",
"AHH",
"AHPA",
"AHPAU",
"AHPAW",
"AHPI",
"AHT",
"AI",
"AIC",
"AIF",
"AIG",
"AIH",
"AIHS",
"AIKI",
"AIM",
"AIMC",
"AIN",
"AINC",
"AINV",
"AIO",
"AIP",
"AIR",
"AIRC",
"AIRG",
"AIRI",
"AIRS",
"AIRT",
"AIRTP",
"AIT",
"AIV",
"AIZ",
"AIZN",
"AJG",
"AJRD",
"AJX",
"AJXA",
"AKA",
"AKAM",
"AKBA",
"AKIC",
"AKICU",
"AKICW",
"AKR",
"AKRO",
"AKTS",
"AKTX",
"AKU",
"AKUS",
"AKYA",
"AL",
"ALAC",
"ALACR",
"ALACW",
"ALB",
"ALBO",
"ALC",
"ALCC",
"ALCO",
"ALDX",
"ALE",
"ALEC",
"ALEX",
"ALF",
"ALFIW",
"ALG",
"ALGM",
"ALGN",
"ALGS",
"ALGT",
"ALHC",
"ALIM",
"ALIT",
"ALJJ",
"ALK",
"ALKS",
"ALKT",
"ALL",
"ALLE",
"ALLK",
"ALLO",
"ALLT",
"ALLY",
"ALNA",
"ALNY",
"ALOT",
"ALPA",
"ALPAU",
"ALPAW",
"ALPN",
"ALPP",
"ALRM",
"ALRN",
"ALRS",
"ALSN",
"ALT",
"ALTG",
"ALTM",
"ALTO",
"ALTR",
"ALTU",
"ALTUU",
"ALTUW",
"ALV",
"ALVR",
"ALX",
"ALXO",
"ALYA",
"ALZN",
"AM",
"AMAL",
"AMAM",
"AMAO",
"AMAOU",
"AMAOW",
"AMAT",
"AMBA",
"AMBC",
"AMBO",
"AMBP",
"AMC",
"AMCI",
"AMCIW",
"AMCR",
"AMCX",
"AMD",
"AME",
"AMED",
"AMEH",
"AMG",
"AMGN",
"AMH",
"AMK",
"AMKR",
"AMN",
"AMNB",
"AMOT",
"AMOV",
"AMP",
"AMPE",
"AMPG",
"AMPGW",
"AMPH",
"AMPI",
"AMPL",
"AMPY",
"AMR",
"AMRC",
"AMRK",
"AMRN",
"AMRS",
"AMRX",
"AMS",
"AMSC",
"AMSF",
"AMST",
"AMSWA",
"AMT",
"AMTB",
"AMTBB",
"AMTI",
"AMTX",
"AMWD",
"AMWL",
"AMX",
"AMYT",
"AMZN",
"AN",
"ANAB",
"ANAC",
"ANAT",
"ANDE",
"ANEB",
"ANET",
"ANF",
"ANGI",
"ANGN",
"ANGO",
"ANIK",
"ANIP",
"ANIX",
"ANNX",
"ANPC",
"ANSS",
"ANTE",
"ANTM",
"ANVS",
"ANY",
"ANZU",
"ANZUU",
"ANZUW",
"AOD",
"AOMR",
"AON",
"AOS",
"AOSL",
"AOUT",
"AP",
"APA",
"APAC",
"APACU",
"APACW",
"APAM",
"APD",
"APDN",
"APEI",
"APEN",
"APG",
"APGB",
"APH",
"API",
"APLE",
"APLS",
"APLT",
"APM",
"APMI",
"APMIU",
"APMIW",
"APO",
"APOG",
"APP",
"APPF",
"APPH",
"APPHW",
"APPN",
"APPS",
"APR",
"APRE",
"APRN",
"APSG",
"APT",
"APTM",
"APTMU",
"APTMW",
"APTO",
"APTS",
"APTV",
"APTX",
"APVO",
"APWC",
"APYX",
"AQB",
"AQMS",
"AQN",
"AQNA",
"AQNB",
"AQNU",
"AQST",
"AQUA",
"AR",
"ARAV",
"ARAY",
"ARBE",
"ARBEW",
"ARBG",
"ARBGU",
"ARBGW",
"ARBK",
"ARC",
"ARCB",
"ARCC",
"ARCE",
"ARCH",
"ARCKU",
"ARCO",
"ARCT",
"ARDC",
"ARDS",
"ARDX",
"ARE",
"AREC",
"ARES",
"ARGD",
"ARGO",
"ARGUU",
"ARGX",
"ARHS",
"ARI",
"ARIS",
"ARKO",
"ARKOW",
"ARKR",
"ARL",
"ARLO",
"ARLP",
"ARMK",
"ARMP",
"ARNA",
"ARNC",
"AROC",
"AROW",
"ARQQ",
"ARQQW",
"ARQT",
"ARR",
"ARRW",
"ARRWU",
"ARRWW",
"ARRY",
"ARTA",
"ARTAU",
"ARTAW",
"ARTEU",
"ARTL",
"ARTLW",
"ARTNA",
"ARTW",
"ARVL",
"ARVN",
"ARW",
"ARWR",
"ARYD",
"ARYE",
"ASA",
"ASAI",
"ASAN",
"ASAQ",
"ASAX",
"ASAXW",
"ASB",
"ASC",
"ASG",
"ASGI",
"ASGN",
"ASH",
"ASIX",
"ASLE",
"ASLEW",
"ASLN",
"ASM",
"ASMB",
"ASML",
"ASND",
"ASO",
"ASPA",
"ASPAW",
"ASPC",
"ASPCU",
"ASPCW",
"ASPN",
"ASPS",
"ASPU",
"ASR",
"ASRT",
"ASRV",
"ASTC",
"ASTE",
"ASTL",
"ASTLW",
"ASTR",
"ASTRW",
"ASTS",
"ASTSW",
"ASUR",
"ASX",
"ASXC",
"ASYS",
"ASZ",
"ATA",
"ATAI",
"ATAQ",
"ATAX",
"ATC",
"ATCO",
"ATCOL",
"ATCX",
"ATEC",
"ATEN",
"ATER",
"ATEX",
"ATGE",
"ATH",
"ATHA",
"ATHE",
"ATHM",
"ATHN",
"ATHX",
"ATI",
"ATIF",
"ATIP",
"ATKR",
"ATLC",
"ATLCP",
"ATLO",
"ATMR",
"ATNF",
"ATNFW",
"ATNI",
"ATNM",
"ATNX",
"ATO",
"ATOM",
"ATOS",
"ATR",
"ATRA",
"ATRC",
"ATRI",
"ATRO",
"ATRS",
"ATSG",
"ATSPT",
"ATSPU",
"ATSPW",
"ATTO",
"ATUS",
"ATVC",
"ATVCU",
"ATVCW",
"ATVI",
"ATXI",
"ATXS",
"ATY",
"AU",
"AUB",
"AUBAP",
"AUBN",
"AUD",
"AUDC",
"AUGX",
"AUID",
"AUMN",
"AUPH",
"AUR",
"AURA",
"AURC",
"AURCU",
"AURCW",
"AUROW",
"AUS",
"AUTL",
"AUTO",
"AUUD",
"AUUDW",
"AUVI",
"AUVIP",
"AUY",
"AVA",
"AVACU",
"AVAH",
"AVAL",
"AVAN",
"AVAV",
"AVB",
"AVCO",
"AVCT",
"AVCTW",
"AVD",
"AVDL",
"AVDX",
"AVEO",
"AVGO",
"AVGOP",
"AVGR",
"AVHIU",
"AVID",
"AVIR",
"AVK",
"AVLR",
"AVNS",
"AVNT",
"AVNW",
"AVO",
"AVPT",
"AVPTW",
"AVRO",
"AVT",
"AVTE",
"AVTR",
"AVTX",
"AVXL",
"AVY",
"AVYA",
"AWF",
"AWH",
"AWI",
"AWK",
"AWP",
"AWR",
"AWRE",
"AWX",
"AX",
"AXDX",
"AXGN",
"AXL",
"AXLA",
"AXNX",
"AXON",
"AXP",
"AXR",
"AXS",
"AXSM",
"AXTA",
"AXTI",
"AXU",
"AY",
"AYI",
"AYLA",
"AYRO",
"AYTU",
"AYX",
"AZEK",
"AZN",
"AZO",
"AZPN",
"AZRE",
"AZUL",
"AZYO",
"AZZ",
"B",
"BA",
"BABA",
"BAC",
"BAH",
"BAK",
"BALY",
"BAM",
"BAMH",
"BAMI",
"BAMR",
"BANC",
"BAND",
"BANF",
"BANR",
"BANX",
"BAOS",
"BAP",
"BARK",
"BASE",
"BATL",
"BATRA",
"BATRK",
"BAX",
"BB",
"BBAR",
"BBBY",
"BBCP",
"BBD",
"BBDC",
"BBDO",
"BBGI",
"BBI",
"BBIG",
"BBIO",
"BBL",
"BBLG",
"BBLGW",
"BBLN",
"BBN",
"BBQ",
"BBSI",
"BBU",
"BBVA",
"BBW",
"BBWI",
"BBY",
"BC",
"BCAB",
"BCAC",
"BCACU",
"BCACW",
"BCAT",
"BCBP",
"BCC",
"BCDA",
"BCE",
"BCEL",
"BCH",
"BCLI",
"BCML",
"BCO",
"BCOR",
"BCOV",
"BCOW",
"BCPC",
"BCRX",
"BCS",
"BCSF",
"BCTX",
"BCTXW",
"BCV",
"BCX",
"BCYC",
"BDC",
"BDJ",
"BDL",
"BDN",
"BDR",
"BDSI",
"BDSX",
"BDTX",
"BDX",
"BDXB",
"BE",
"BEAM",
"BECN",
"BEDU",
"BEEM",
"BEEMW",
"BEKE",
"BELFA",
"BELFB",
"BEN",
"BENE",
"BENER",
"BENEU",
"BENEW",
"BEP",
"BEPC",
"BEPH",
"BERY",
"BEST",
"BFAM",
"BFC",
"BFI",
"BFIIW",
"BFIN",
"BFK",
"BFLY",
"BFRA",
"BFRI",
"BFRIW",
"BFS",
"BFST",
"BFZ",
"BG",
"BGB",
"BGCP",
"BGFV",
"BGH",
"BGI",
"BGIO",
"BGNE",
"BGR",
"BGRY",
"BGRYW",
"BGS",
"BGSF",
"BGSX",
"BGT",
"BGX",
"BGY",
"BH",
"BHACU",
"BHAT",
"BHB",
"BHC",
"BHE",
"BHF",
"BHFAL",
"BHFAN",
"BHFAO",
"BHFAP",
"BHG",
"BHIL",
"BHK",
"BHLB",
"BHP",
"BHR",
"BHSE",
"BHSEW",
"BHTG",
"BHV",
"BHVN",
"BIDU",
"BIF",
"BIG",
"BIGC",
"BIGZ",
"BIIB",
"BILI",
"BILL",
"BIMI",
"BIO",
"BIOC",
"BIOL",
"BIOT",
"BIOTU",
"BIOTW",
"BIOX",
"BIP",
"BIPC",
"BIPH",
"BIRD",
"BIT",
"BITE",
"BITF",
"BIVI",
"BJ",
"BJRI",
"BK",
"BKCC",
"BKD",
"BKE",
"BKEP",
"BKEPP",
"BKH",
"BKI",
"BKKT",
"BKN",
"BKNG",
"BKR",
"BKSC",
"BKSY",
"BKT",
"BKTI",
"BKU",
"BKYI",
"BL",
"BLBD",
"BLCM",
"BLCT",
"BLD",
"BLDE",
"BLDEW",
"BLDP",
"BLDR",
"BLE",
"BLFS",
"BLFY",
"BLI",
"BLIN",
"BLK",
"BLKB",
"BLL",
"BLMN",
"BLND",
"BLNG",
"BLNGW",
"BLNK",
"BLNKW",
"BLPH",
"BLRX",
"BLSA",
"BLTS",
"BLTSU",
"BLTSW",
"BLU",
"BLUA",
"BLUE",
"BLW",
"BLX",
"BMA",
"BMAQ",
"BMAQR",
"BMAQU",
"BMAQW",
"BMBL",
"BME",
"BMEA",
"BMEZ",
"BMI",
"BMO",
"BMRA",
"BMRC",
"BMRN",
"BMTC",
"BMTX",
"BMY",
"BNED",
"BNFT",
"BNGO",
"BNGOW",
"BNIX",
"BNIXR",
"BNIXW",
"BNL",
"BNNR",
"BNNRU",
"BNNRW",
"BNR",
"BNS",
"BNSO",
"BNTC",
"BNTX",
"BNY",
"BOAC",
"BOAS",
"BODY",
"BOE",
"BOH",
"BOKF",
"BOLT",
"BOMN",
"BON",
"BOOM",
"BOOT",
"BORR",
"BOSC",
"BOTJ",
"BOX",
"BOXL",
"BP",
"BPMC",
"BPMP",
"BPOP",
"BPOPM",
"BPRN",
"BPT",
"BPTH",
"BPTS",
"BPYPM",
"BPYPN",
"BPYPO",
"BPYPP",
"BQ",
"BR",
"BRAG",
"BRBR",
"BRBS",
"BRC",
"BRCN",
"BRDG",
"BRDS",
"BREZ",
"BREZR",
"BREZW",
"BRFS",
"BRG",
"BRID",
"BRIV",
"BRIVU",
"BRIVW",
"BRKL",
"BRKR",
"BRKS",
"BRLI",
"BRLIR",
"BRLIW",
"BRLT",
"BRMK",
"BRN",
"BRO",
"BROG",
"BROGW",
"BROS",
"BRP",
"BRPM",
"BRPMU",
"BRPMW",
"BRQS",
"BRSP",
"BRT",
"BRTX",
"BRW",
"BRX",
"BRY",
"BSA",
"BSAC",
"BSAQ",
"BSBK",
"BSBR",
"BSET",
"BSFC",
"BSGA",
"BSGAR",
"BSGAU",
"BSGM",
"BSIG",
"BSKY",
"BSKYU",
"BSKYW",
"BSL",
"BSM",
"BSMX",
"BSN",
"BSQR",
"BSRR",
"BST",
"BSTZ",
"BSVN",
"BSX",
"BSY",
"BTA",
"BTAI",
"BTAQ",
"BTAQU",
"BTAQW",
"BTB",
"BTBT",
"BTCM",
"BTCS",
"BTCY",
"BTG",
"BTI",
"BTN",
"BTNB",
"BTO",
"BTRS",
"BTRSW",
"BTT",
"BTTR",
"BTTX",
"BTU",
"BTWN",
"BTWNU",
"BTWNW",
"BTX",
"BTZ",
"BUD",
"BUI",
"BUR",
"BURL",
"BUSE",
"BV",
"BVH",
"BVN",
"BVS",
"BVXV",
"BW",
"BWA",
"BWAC",
"BWACU",
"BWACW",
"BWAY",
"BWB",
"BWBBP",
"BWC",
"BWCAU",
"BWEN",
"BWFG",
"BWG",
"BWMN",
"BWMX",
"BWSN",
"BWXT",
"BX",
"BXC",
"BXMT",
"BXMX",
"BXP",
"BXRX",
"BXSL",
"BY",
"BYD",
"BYFC",
"BYM",
"BYND",
"BYRN",
"BYSI",
"BYTS",
"BYTSU",
"BZ",
"BZH",
"BZUN",
"C",
"CAAP",
"CAAS",
"CABA",
"CABO",
"CAC",
"CACC",
"CACI",
"CADE",
"CADL",
"CAE",
"CAF",
"CAG",
"CAH",
"CAI",
"CAJ",
"CAKE",
"CAL",
"CALA",
"CALB",
"CALM",
"CALT",
"CALX",
"CAMP",
"CAMT",
"CAN",
"CANF",
"CANG",
"CANO",
"CAPL",
"CAPR",
"CAR",
"CARA",
"CARE",
"CARG",
"CARR",
"CARS",
"CARV",
"CAS",
"CASA",
"CASH",
"CASI",
"CASS",
"CASY",
"CAT",
"CATC",
"CATO",
"CATY",
"CB",
"CBAH",
"CBAN",
"CBAT",
"CBAY",
"CBD",
"CBFV",
"CBH",
"CBIO",
"CBL",
"CBNK",
"CBOE",
"CBRE",
"CBRL",
"CBSH",
"CBT",
"CBTX",
"CBU",
"CBZ",
"CC",
"CCAC",
"CCAI",
"CCAIU",
"CCAIW",
"CCAP",
"CCB",
"CCBG",
"CCCC",
"CCCS",
"CCD",
"CCEL",
"CCEP",
"CCF",
"CCI",
"CCJ",
"CCK",
"CCL",
"CCLP",
"CCM",
"CCMP",
"CCNC",
"CCNE",
"CCNEP",
"CCO",
"CCOI",
"CCRN",
"CCS",
"CCSI",
"CCTSU",
"CCU",
"CCV",
"CCVI",
"CCXI",
"CCZ",
"CD",
"CDAK",
"CDAQU",
"CDAY",
"CDE",
"CDEV",
"CDK",
"CDLX",
"CDMO",
"CDNA",
"CDNS",
"CDOR",
"CDR",
"CDRE",
"CDTX",
"CDW",
"CDXC",
"CDXS",
"CDZI",
"CDZIP",
"CE",
"CEA",
"CECE",
"CEE",
"CEI",
"CEIX",
"CELC",
"CELH",
"CELP",
"CELU",
"CELUW",
"CEM",
"CEMI",
"CEN",
"CENQ",
"CENQU",
"CENQW",
"CENT",
"CENTA",
"CENX",
"CEPU",
"CEQP",
"CERE",
"CERN",
"CERS",
"CERT",
"CET",
"CETX",
"CETXP",
"CETXW",
"CEV",
"CEVA",
"CF",
"CFB",
"CFBK",
"CFFE",
"CFFEU",
"CFFEW",
"CFFI",
"CFFN",
"CFFVU",
"CFFVW",
"CFG",
"CFIV",
"CFIVU",
"CFIVW",
"CFLT",
"CFMS",
"CFR",
"CFRX",
"CFV",
"CFVI",
"CFVIU",
"CFVIW",
"CFX",
"CFXA",
"CG",
"CGA",
"CGABL",
"CGAU",
"CGBD",
"CGC",
"CGEM",
"CGEN",
"CGNT",
"CGNX",
"CGO",
"CGRN",
"CGTX",
"CHAA",
"CHCI",
"CHCO",
"CHCT",
"CHD",
"CHDN",
"CHE",
"CHEF",
"CHEK",
"CHEKZ",
"CHGG",
"CHH",
"CHI",
"CHK",
"CHKEL",
"CHKEW",
"CHKEZ",
"CHKP",
"CHMG",
"CHMI",
"CHN",
"CHNG",
"CHNGU",
"CHNR",
"CHPM",
"CHPMU",
"CHPMW",
"CHPT",
"CHRA",
"CHRB",
"CHRS",
"CHRW",
"CHS",
"CHSCL",
"CHSCM",
"CHSCN",
"CHSCO",
"CHSCP",
"CHT",
"CHTR",
"CHUY",
"CHW",
"CHWA",
"CHWAU",
"CHWAW",
"CHWY",
"CHX",
"CHY",
"CI",
"CIA",
"CIAN",
"CIB",
"CIDM",
"CIEN",
"CIF",
"CIFR",
"CIFRW",
"CIG",
"CIGI",
"CIH",
"CII",
"CIIG",
"CIIGU",
"CIIGW",
"CIK",
"CIM",
"CINF",
"CINR",
"CIO",
"CION",
"CIR",
"CIT",
"CIVB",
"CIVI",
"CIX",
"CIXX",
"CIZN",
"CJJD",
"CKPT",
"CKX",
"CL",
"CLAA",
"CLAQ",
"CLAQU",
"CLAQW",
"CLAR",
"CLAS",
"CLAYW",
"CLB",
"CLBK",
"CLBS",
"CLBT",
"CLBTW",
"CLDT",
"CLDX",
"CLEU",
"CLF",
"CLFD",
"CLGN",
"CLH",
"CLI",
"CLIM",
"CLIR",
"CLLS",
"CLM",
"CLMT",
"CLNE",
"CLNN",
"CLNNW",
"CLOE",
"CLOER",
"CLOEU",
"CLOV",
"CLPR",
"CLPS",
"CLPT",
"CLR",
"CLRB",
"CLRMW",
"CLRO",
"CLS",
"CLSD",
"CLSK",
"CLSN",
"CLST",
"CLVR",
"CLVRW",
"CLVS",
"CLVT",
"CLW",
"CLWT",
"CLX",
"CLXT",
"CM",
"CMA",
"CMAX",
"CMAXW",
"CMBM",
"CMC",
"CMCL",
"CMCM",
"CMCO",
"CMCSA",
"CMCT",
"CME",
"CMG",
"CMI",
"CMLS",
"CMLT",
"CMLTU",
"CMLTW",
"CMMB",
"CMP",
"CMPI",
"CMPR",
"CMPS",
"CMPX",
"CMRE",
"CMRX",
"CMS",
"CMSA",
"CMSC",
"CMSD",
"CMT",
"CMTG",
"CMTL",
"CMU",
"CNA",
"CNBKA",
"CNC",
"CNCE",
"CND",
"CNDA",
"CNDT",
"CNET",
"CNEY",
"CNF",
"CNFR",
"CNFRL",
"CNHI",
"CNI",
"CNK",
"CNM",
"CNMD",
"CNNB",
"CNNE",
"CNO",
"CNOB",
"CNOBP",
"CNP",
"CNQ",
"CNR",
"CNS",
"CNSL",
"CNSP",
"CNTA",
"CNTB",
"CNTG",
"CNTQ",
"CNTQU",
"CNTQW",
"CNTX",
"CNTY",
"CNVY",
"CNX",
"CNXC",
"CNXN",
"CO",
"COCO",
"COCP",
"CODA",
"CODI",
"CODX",
"COE",
"COF",
"COFS",
"COGT",
"COHN",
"COHR",
"COHU",
"COIN",
"COKE",
"COLB",
"COLD",
"COLI",
"COLIU",
"COLIW",
"COLL",
"COLM",
"COMM",
"COMP",
"COMS",
"COMSP",
"COMSW",
"CONE",
"CONN",
"CONX",
"CONXU",
"CONXW",
"COO",
"COOK",
"COOL",
"COOLU",
"COOLW",
"COOP",
"COP",
"COR",
"CORR",
"CORS",
"CORT",
"COST",
"COTY",
"COUP",
"COUR",
"COVA",
"COVAU",
"COVAW",
"COWN",
"COWNL",
"CP",
"CPA",
"CPAA",
"CPAAW",
"CPAC",
"CPAR",
"CPARU",
"CPARW",
"CPB",
"CPE",
"CPF",
"CPG",
"CPHC",
"CPHI",
"CPIX",
"CPK",
"CPLG",
"CPLP",
"CPNG",
"CPOP",
"CPRI",
"CPRT",
"CPRX",
"CPS",
"CPSH",
"CPSI",
"CPSR",
"CPSS",
"CPT",
"CPTAG",
"CPTAL",
"CPTK",
"CPUH",
"CPZ",
"CQP",
"CR",
"CRAI",
"CRBP",
"CRBU",
"CRC",
"CRCT",
"CRDF",
"CRDL",
"CREG",
"CRESW",
"CRESY",
"CREX",
"CREXW",
"CRF",
"CRH",
"CRHC",
"CRI",
"CRIS",
"CRK",
"CRKN",
"CRL",
"CRM",
"CRMD",
"CRMT",
"CRNC",
"CRNT",
"CRNX",
"CRON",
"CROX",
"CRS",
"CRSP",
"CRSR",
"CRT",
"CRTD",
"CRTDW",
"CRTO",
"CRTX",
"CRU",
"CRUS",
"CRVL",
"CRVS",
"CRWD",
"CRWS",
"CRXT",
"CRXTW",
"CRY",
"CRZN",
"CRZNU",
"CS",
"CSAN",
"CSBR",
"CSCO",
"CSCW",
"CSGP",
"CSGS",
"CSII",
"CSIQ",
"CSL",
"CSLT",
"CSPI",
"CSPR",
"CSQ",
"CSR",
"CSSE",
"CSSEN",
"CSSEP",
"CSTA",
"CSTE",
"CSTL",
"CSTM",
"CSTR",
"CSU",
"CSV",
"CSWC",
"CSWI",
"CSX",
"CTAQ",
"CTAQU",
"CTAQW",
"CTAS",
"CTBB",
"CTBI",
"CTDD",
"CTEK",
"CTG",
"CTHR",
"CTIB",
"CTIC",
"CTK",
"CTKB",
"CTLP",
"CTLT",
"CTMX",
"CTO",
"CTOS",
"CTR",
"CTRA",
"CTRE",
"CTRM",
"CTRN",
"CTS",
"CTSH",
"CTSO",
"CTT",
"CTVA",
"CTXR",
"CTXRW",
"CTXS",
"CUBA",
"CUBB",
"CUBE",
"CUBI",
"CUE",
"CUEN",
"CUENW",
"CUK",
"CULL",
"CULP",
"CURI",
"CURIW",
"CURO",
"CURV",
"CUTR",
"CUZ",
"CVA",
"CVAC",
"CVBF",
"CVCO",
"CVCY",
"CVE",
"CVEO",
"CVET",
"CVGI",
"CVGW",
"CVI",
"CVII",
"CVLG",
"CVLT",
"CVLY",
"CVM",
"CVNA",
"CVR",
"CVRX",
"CVS",
"CVU",
"CVV",
"CVX",
"CW",
"CWAN",
"CWBC",
"CWBR",
"CWCO",
"CWEN",
"CWH",
"CWK",
"CWST",
"CWT",
"CX",
"CXDO",
"CXE",
"CXH",
"CXM",
"CXP",
"CXW",
"CYAD",
"CYAN",
"CYBE",
"CYBN",
"CYBR",
"CYCC",
"CYCCP",
"CYCN",
"CYD",
"CYH",
"CYN",
"CYRN",
"CYRX",
"CYT",
"CYTH",
"CYTHW",
"CYTK",
"CYTO",
"CYXT",
"CYXTW",
"CZNC",
"CZOO",
"CZR",
"CZWI",
"D",
"DAC",
"DADA",
"DAIO",
"DAKT",
"DAL",
"DALN",
"DALS",
"DAN",
"DAO",
"DAR",
"DARE",
"DASH",
"DATS",
"DATSW",
"DAVA",
"DAWN",
"DB",
"DBD",
"DBDR",
"DBDRU",
"DBDRW",
"DBGI",
"DBGIW",
"DBI",
"DBL",
"DBRG",
"DBTX",
"DBVT",
"DBX",
"DCBO",
"DCF",
"DCGO",
"DCGOW",
"DCI",
"DCO",
"DCOM",
"DCOMP",
"DCP",
"DCPH",
"DCRC",
"DCRCU",
"DCRCW",
"DCRD",
"DCRDU",
"DCRDW",
"DCRN",
"DCRNU",
"DCRNW",
"DCT",
"DCTH",
"DCUE",
"DD",
"DDD",
"DDF",
"DDI",
"DDL",
"DDMX",
"DDMXU",
"DDMXW",
"DDOG",
"DDS",
"DDT",
"DE",
"DEA",
"DECK",
"DEI",
"DELL",
"DEN",
"DENN",
"DEO",
"DESP",
"DEX",
"DFFN",
"DFH",
"DFIN",
"DFP",
"DFPH",
"DFPHU",
"DFPHW",
"DFS",
"DG",
"DGICA",
"DGICB",
"DGII",
"DGLY",
"DGNS",
"DGNU",
"DGX",
"DH",
"DHACU",
"DHBC",
"DHBCU",
"DHBCW",
"DHC",
"DHCA",
"DHCAU",
"DHCAW",
"DHCNI",
"DHCNL",
"DHF",
"DHHC",
"DHHCU",
"DHI",
"DHIL",
"DHR",
"DHT",
"DHX",
"DHY",
"DIAX",
"DIBS",
"DICE",
"DIDI",
"DILA",
"DILAW",
"DIN",
"DIOD",
"DIS",
"DISA",
"DISAU",
"DISAW",
"DISCA",
"DISCB",
"DISCK",
"DISH",
"DIT",
"DJCO",
"DK",
"DKDCA",
"DKDCU",
"DKDCW",
"DKL",
"DKNG",
"DKS",
"DLA",
"DLB",
"DLCA",
"DLCAU",
"DLCAW",
"DLHC",
"DLNG",
"DLO",
"DLPN",
"DLR",
"DLTH",
"DLTR",
"DLX",
"DLY",
"DM",
"DMAC",
"DMAQU",
"DMB",
"DMF",
"DMLP",
"DMO",
"DMRC",
"DMS",
"DMTK",
"DMYQ",
"DNA",
"DNAA",
"DNAB",
"DNAC",
"DNAD",
"DNAY",
"DNB",
"DNLI",
"DNMR",
"DNN",
"DNOW",
"DNP",
"DNUT",
"DNZ",
"DOC",
"DOCN",
"DOCS",
"DOCU",
"DOGZ",
"DOLE",
"DOMA",
"DOMO",
"DOOO",
"DOOR",
"DORM",
"DOV",
"DOW",
"DOX",
"DOYU",
"DPG",
"DPRO",
"DPW",
"DPZ",
"DQ",
"DRAY",
"DRAYU",
"DRAYW",
"DRD",
"DRE",
"DRH",
"DRI",
"DRIO",
"DRMA",
"DRMAW",
"DRNA",
"DRQ",
"DRRX",
"DRTT",
"DRUG",
"DRVN",
"DS",
"DSAC",
"DSACU",
"DSACW",
"DSEY",
"DSGN",
"DSGX",
"DSKE",
"DSKEW",
"DSL",
"DSM",
"DSP",
"DSPG",
"DSS",
"DSU",
"DSWL",
"DSX",
"DT",
"DTB",
"DTC",
"DTE",
"DTEA",
"DTF",
"DTIL",
"DTM",
"DTOC",
"DTOCU",
"DTOCW",
"DTP",
"DTRT",
"DTRTU",
"DTRTW",
"DTSS",
"DTST",
"DTSTW",
"DTW",
"DTY",
"DUK",
"DUKB",
"DUNE",
"DUNEU",
"DUNEW",
"DUO",
"DUOL",
"DUOT",
"DV",
"DVA",
"DVAX",
"DVD",
"DVN",
"DWAC",
"DWACU",
"DWACW",
"DWIN",
"DWSN",
"DX",
"DXC",
"DXCM",
"DXF",
"DXLG",
"DXPE",
"DXR",
"DXYN",
"DY",
"DYAI",
"DYFN",
"DYN",
"DYNS",
"DYNT",
"DZSI",
"E",
"EA",
"EAC",
"EACPW",
"EAD",
"EAF",
"EAI",
"EAR",
"EARN",
"EAST",
"EAT",
"EB",
"EBAC",
"EBACU",
"EBACW",
"EBAY",
"EBC",
"EBET",
"EBF",
"EBIX",
"EBMT",
"EBON",
"EBR",
"EBS",
"EBSB",
"EBTC",
"EC",
"ECAT",
"ECC           ",
"ECCB",
"ECCC",
"ECCW",
"ECCX",
"ECCY",
"ECF",
"ECHO",
"ECL",
"ECOL",
"ECOLW",
"ECOM          ",
"ECOR",
"ECPG",
"ECVT",
"ED",
"EDAP",
"EDD",
"EDF",
"EDI",
"EDIT",
"EDN",
"EDNC",
"EDNCU",
"EDNCW",
"EDR",
"EDRY",
"EDSA",
"EDTK",
"EDTX",
"EDTXW",
"EDU",
"EDUC",
"EEA",
"EEFT",
"EEIQ",
"EEX",
"EFC",
"EFL",
"EFOI",
"EFR",
"EFSC",
"EFT",
"EFTR",
"EFTRW",
"EFX",
"EGAN",
"EGBN",
"EGF",
"EGGF",
"EGHT",
"EGLE",
"EGLX",
"EGO",
"EGP",
"EGRX",
"EGY",
"EH",
"EHC",
"EHI",
"EHTH",
"EIC",
"EICA",
"EIG",
"EIGR",
"EIM",
"EIX",
"EJFA",
"EJFAU",
"EJFAW",
"EJH",
"EKSO",
"EL",
"ELA",
"ELAN",
"ELAT",
"ELC",
"ELDN",
"ELEV",
"ELF",
"ELLO",
"ELMD",
"ELMS",
"ELMSW",
"ELOX",
"ELP",
"ELS",
"ELSE",
"ELTK",
"ELVT",
"ELY",
"ELYM",
"ELYS",
"EM",
"EMAN",
"EMCF",
"EMD",
"EME",
"EMF",
"EMKR",
"EML",
"EMN",
"EMO",
"EMP",
"EMR",
"EMX",
"ENB",
"ENBA",
"ENBL",
"ENDP",
"ENERU",
"ENFA",
"ENFAU",
"ENFAW",
"ENFN",
"ENG",
"ENIA",
"ENIC",
"ENJ",
"ENJY",
"ENJYW",
"ENLC",
"ENLV",
"ENNV",
"ENNVU",
"ENNVW",
"ENO",
"ENOB",
"ENPC",
"ENPH",
"ENR",
"ENS",
"ENSC",
"ENSG",
"ENSV",
"ENTA",
"ENTFU",
"ENTG",
"ENTX",
"ENTXW",
"ENV",
"ENVA",
"ENVB",
"ENVI",
"ENVIU",
"ENVIW",
"ENVX",
"ENVXW",
"ENX",
"ENZ",
"EOCW",
"EOD",
"EOG",
"EOI",
"EOLS",
"EOS",
"EOSE",
"EOSEW",
"EOT",
"EPAC",
"EPAM",
"EPAY",
"EPC",
"EPD",
"EPHY",
"EPHYU",
"EPHYW",
"EPIX",
"EPM",
"EPR",
"EPRT",
"EPSN",
"EPWR",
"EPZM",
"EQ",
"EQBK",
"EQC",
"EQD",
"EQH",
"EQIX",
"EQNR",
"EQOS",
"EQR",
"EQS",
"EQT",
"EQX",
"ERAS",
"ERC",
"ERES",
"ERESU",
"ERESW",
"ERF",
"ERH",
"ERIC",
"ERIE",
"ERII",
"ERJ",
"ERO",
"ERYP",
"ES",
"ESACU",
"ESBK",
"ESCA",
"ESE",
"ESEA",
"ESGC",
"ESGR",
"ESGRO",
"ESGRP",
"ESI",
"ESLT",
"ESM",
"ESMT",
"ESNT",
"ESP",
"ESPR",
"ESQ",
"ESRT",
"ESS",
"ESSA",
"ESSC",
"ESSCR",
"ESSCU",
"ESSCW",
"ESTA",
"ESTC",
"ESTE",
"ESXB",
"ET",
"ETAC",
"ETACU",
"ETACW",
"ETB",
"ETD",
"ETG",
"ETJ",
"ETN",
"ETNB",
"ETO",
"ETON",
"ETR",
"ETRN",
"ETSY",
"ETTX",
"ETV",
"ETW",
"ETWO",
"ETX           ",
"ETY",
"EUCR",
"EUCRU",
"EUCRW",
"EURN",
"EUSG",
"EUSGW",
"EVA",
"EVAX",
"EVBG",
"EVBN",
"EVC",
"EVCM",
"EVER",
"EVF",
"EVFM",
"EVG",
"EVGN",
"EVGO",
"EVGOW",
"EVH",
"EVI",
"EVK",
"EVLMC",
"EVLO",
"EVLV",
"EVLVW",
"EVM",
"EVN",
"EVO",
"EVOJ",
"EVOJU",
"EVOJW",
"EVOK",
"EVOL",
"EVOP",
"EVR",
"EVRG",
"EVRI",
"EVT",
"EVTC",
"EVV",
"EW",
"EWBC",
"EWCZ",
"EWTX",
"EXAI",
"EXAS",
"EXC",
"EXD",
"EXEL",
"EXG",
"EXK",
"EXLS",
"EXN",
"EXP",
"EXPD",
"EXPE",
"EXPI",
"EXPO",
"EXPR",
"EXR",
"EXTN",
"EXTR",
"EYE",
"EYEN",
"EYES",
"EYESW",
"EYPT",
"EZFL",
"EZGO",
"EZPW",
"F",
"FA",
"FACA",
"FACT",
"FAF",
"FAM",
"FAMI",
"FANG",
"FANH",
"FARM",
"FARO",
"FAST",
"FAT",
"FATBB",
"FATBP",
"FATBW",
"FATE",
"FATPU",
"FAX",
"FB",
"FBC",
"FBHS",
"FBIO",
"FBIOP",
"FBIZ",
"FBK",
"FBMS",
"FBNC",
"FBP",
"FBRT",
"FBRX",
"FC",
"FCAP",
"FCAX",
"FCBC",
"FCCO",
"FCCY",
"FCEL",
"FCF",
"FCFS",
"FCN",
"FCNCA",
"FCNCP",
"FCO",
"FCPT",
"FCRD",
"FCRW",
"FCT",
"FCUV",
"FCX",
"FDBC",
"FDEU",
"FDMT",
"FDP",
"FDS",
"FDUS",
"FDX",
"FE",
"FEDU",
"FEI           ",
"FEIM",
"FELE",
"FEMY",
"FEN",
"FENC",
"FENG",
"FEO",
"FERG",
"FET",
"FEXDU",
"FF",
"FFA",
"FFBC",
"FFBW",
"FFC",
"FFHL",
"FFIC",
"FFIE",
"FFIEW",
"FFIN",
"FFIV",
"FFNW",
"FFWM",
"FGB",
"FGBI",
"FGBIP",
"FGEN",
"FGF",
"FGFPP",
"FHB",
"FHI",
"FHLTU",
"FHN",
"FHS",
"FHTX",
"FIACU",
"FIBK",
"FICO",
"FICVU",
"FICVW",
"FIF",
"FIGS",
"FINM",
"FINMU",
"FINMW",
"FINS",
"FINV",
"FIS",
"FISI",
"FISV",
"FITB",
"FITBI",
"FITBO",
"FITBP",
"FIV",
"FIVE",
"FIVN",
"FIX",
"FIXX",
"FIZZ",
"FKWL",
"FL",
"FLAC",
"FLACW",
"FLAG",
"FLC",
"FLDM",
"FLEX",
"FLGC",
"FLGT",
"FLIC",
"FLL",
"FLME",
"FLMN",
"FLMNW",
"FLNC",
"FLNG",
"FLNT",
"FLO",
"FLOW",
"FLR",
"FLS",
"FLT",
"FLUX",
"FLWS",
"FLXN",
"FLXS",
"FLYA",
"FLYW",
"FMAC",
"FMAO",
"FMBH",
"FMBI",
"FMBIO",
"FMBIP",
"FMC",
"FMIV",
"FMIVU",
"FMIVW",
"FMN",
"FMNB",
"FMO",
"FMS",
"FMTX",
"FMX",
"FMY",
"FN",
"FNA",
"FNB",
"FNCB",
"FNCH",
"FND",
"FNF",
"FNHC",
"FNKO",
"FNLC",
"FNV",
"FNVTU",
"FNWB",
"FNWD",
"FOA",
"FOCS",
"FOE",
"FOF",
"FOLD",
"FONR",
"FOR",
"FORA",
"FORD",
"FORE",
"FOREU",
"FOREW",
"FORG",
"FORM",
"FORR",
"FORTY",
"FOSL",
"FOUNU",
"FOUR",
"FOX",
"FOXA",
"FOXF",
"FOXW",
"FOXWU",
"FOXWW",
"FPAC",
"FPAY",
"FPF",
"FPH",
"FPI",
"FPL",
"FR",
"FRA",
"FRAF",
"FRBA",
"FRBK",
"FRC",
"FRD",
"FREE",
"FREEW",
"FREQ",
"FREY",
"FRG",
"FRGAP",
"FRGI",
"FRHC",
"FRLAU",
"FRLN",
"FRME",
"FRO",
"FROG",
"FRON",
"FRONU",
"FRONW",
"FRPH",
"FRPT",
"FRSG",
"FRSGU",
"FRSGW",
"FRSH",
"FRST",
"FRSX",
"FRT",
"FRTA",
"FRW",
"FRWAU",
"FRWAW",
"FRXB",
"FSBC",
"FSBW",
"FSD",
"FSEA",
"FSFG",
"FSI",
"FSII",
"FSK",
"FSLR",
"FSLY",
"FSM",
"FSNB",
"FSP",
"FSR",
"FSRX",
"FSRXW",
"FSS",
"FSSI",
"FSSIU",
"FSSIW",
"FST",
"FSTR",
"FSTX",
"FSV",
"FT",
"FTAA",
"FTAAU",
"FTAAW",
"FTAI",
"FTCH",
"FTCI",
"FTCV",
"FTCVU",
"FTCVW",
"FTDR",
"FTEK",
"FTEV",
"FTF",
"FTFT",
"FTHM",
"FTHY",
"FTI",
"FTK",
"FTNT",
"FTPA",
"FTRP",
"FTS",
"FTSI",
"FTV",
"FTVI",
"FTVIU",
"FTVIW",
"FUBO",
"FUL",
"FULC",
"FULT",
"FULTP",
"FUN",
"FUNC",
"FUND",
"FURY",
"FUSB",
"FUSN",
"FUTU",
"FUV",
"FVAM",
"FVCB",
"FVE",
"FVIV",
"FVRR",
"FVT",
"FWAC",
"FWBI",
"FWONA",
"FWONK",
"FWP",
"FWRD",
"FWRG",
"FXLV",
"FXNC",
"FYBR",
"FZT",
"G",
"GAB",
"GABC",
"GACQ",
"GACQU",
"GACQW",
"GAIA",
"GAIN",
"GAINN",
"GAINZ",
"GALT",
"GAM",
"GAMB",
"GAMC",
"GAMCU",
"GAMCW",
"GAME",
"GAN",
"GANX",
"GAPA",
"GASS",
"GATEU",
"GATO",
"GATX",
"GAU",
"GB",
"GBAB",
"GBCI",
"GBDC",
"GBIO",
"GBL",
"GBLI",
"GBLIL",
"GBNH",
"GBNY",
"GBOX",
"GBR",
"GBRGR",
"GBRGU",
"GBRGW",
"GBS",
"GBT",
"GBX",
"GCAC",
"GCACU",
"GCACW",
"GCBC",
"GCI",
"GCMG",
"GCMGW",
"GCO",
"GCP",
"GCV",
"GD",
"GDDY",
"GDEN",
"GDEV",
"GDEVW",
"GDL",
"GDO",
"GDOT",
"GDP",
"GDRX",
"GDS",
"GDV",
"GDYN",
"GE",
"GECC",
"GECCM",
"GECCN",
"GECCO",
"GEF",
"GEG",
"GEL",
"GENC",
"GENE",
"GENI",
"GEO",
"GEOS",
"GER",
"GERN",
"GES",
"GET",
"GEVO",
"GF",
"GFAI",
"GFAIW",
"GFED",
"GFF",
"GFI",
"GFL",
"GFLU",
"GFOR",
"GFS",
"GFX",
"GGAL",
"GGB",
"GGG",
"GGGV",
"GGGVR",
"GGMC",
"GGMCU",
"GGMCW",
"GGN",
"GGPI",
"GGPIU",
"GGPIW",
"GGT",
"GGZ",
"GH",
"GHAC",
"GHACU",
"GHACW",
"GHC",
"GHG",
"GHL",
"GHLD",
"GHM",
"GHRS",
"GHSI",
"GHY",
"GIA",
"GIACU",
"GIB",
"GIC",
"GIFI",
"GIG",
"GIGGU",
"GIGGW",
"GIGM",
"GIII",
"GIIX",
"GIIXU",
"GIIXW",
"GIL",
"GILD",
"GILT",
"GIM",
"GIPR",
"GIPRW",
"GIS",
"GIW",
"GIWWU",
"GIWWW",
"GJH",
"GJO",
"GJP",
"GJR",
"GJS",
"GKOS",
"GL",
"GLAD",
"GLAQ",
"GLAQW",
"GLBE",
"GLBL",
"GLBLU",
"GLBLW",
"GLBS",
"GLBZ",
"GLDD",
"GLDG",
"GLEE",
"GLEEU",
"GLEEW",
"GLG",
"GLHA",
"GLHAU",
"GLHAW",
"GLMD",
"GLNG",
"GLO",
"GLOB",
"GLOP",
"GLP",
"GLPG",
"GLPI",
"GLQ",
"GLRE",
"GLSI",
"GLSPT",
"GLSPU",
"GLSPW",
"GLT",
"GLTA",
"GLTO",
"GLU",
"GLUE",
"GLV",
"GLW",
"GLYC",
"GM",
"GMAB",
"GMBL",
"GMBLW",
"GMBT",
"GMBTU",
"GMBTW",
"GMDA",
"GME",
"GMED",
"GMII",
"GMIIU",
"GMIIW",
"GMRE",
"GMS",
"GMTX",
"GMVD",
"GMVDW",
"GNAC",
"GNACU",
"GNACW",
"GNCA",
"GNE",
"GNFT",
"GNK",
"GNL",
"GNLN",
"GNOG",
"GNPX",
"GNRC",
"GNSS",
"GNT",
"GNTX",
"GNTY",
"GNUS",
"GNW",
"GO",
"GOAC",
"GOBI",
"GOCO",
"GOED",
"GOEV",
"GOEVW",
"GOF",
"GOGL",
"GOGO",
"GOL",
"GOLD",
"GOLF",
"GOOD",
"GOODN",
"GOODO",
"GOOG",
"GOOGL",
"GOOS",
"GORO",
"GOSS",
"GOTU",
"GOVX",
"GOVXW",
"GP",
"GPAC",
"GPACU",
"GPACW",
"GPC",
"GPCO",
"GPCOR",
"GPCOU",
"GPCOW",
"GPI",
"GPJA",
"GPK",
"GPL",
"GPMT",
"GPN",
"GPOR",
"GPP",
"GPRE",
"GPRK",
"GPRO",
"GPS",
"GRAY",
"GRBK",
"GRC",
"GRCL",
"GRCY",
"GRCYW",
"GREE",
"GREEL",
"GRF",
"GRFS",
"GRIL",
"GRIN",
"GRMN",
"GRNQ",
"GROM",
"GROMW",
"GROW",
"GROY",
"GRPH",
"GRPN",
"GRTS",
"GRTX",
"GRUB",
"GRVI",
"GRVY",
"GRWG",
"GRX",
"GS",
"GSAQ",
"GSAQU",
"GSAQW",
"GSAT",
"GSBC",
"GSBD",
"GSEV",
"GSEVU",
"GSEVW",
"GSHD",
"GSIT",
"GSK",
"GSKY",
"GSL",
"GSLD",
"GSM",
"GSMG",
"GSMGW",
"GSQD",
"GSS",
"GSV",
"GT",
"GTACU",
"GTBP",
"GTE",
"GTEC",
"GTES",
"GTH",
"GTHX",
"GTIM",
"GTLB",
"GTLS",
"GTN",
"GTPA",
"GTPAU",
"GTPAW",
"GTPB",
"GTPBW",
"GTS",
"GTX",
"GTXAP",
"GTY",
"GTYH",
"GURE",
"GUT",
"GVA",
"GVP",
"GWB",
"GWGH",
"GWH",
"GWII",
"GWIIW",
"GWRE",
"GWRS",
"GWW",
"GXII",
"GXIIW",
"GXO",
"GYRO",
"H",
"HA",
"HAAC",
"HAACU",
"HAACW",
"HAE",
"HAFC",
"HAIN",
"HAL",
"HALL",
"HALO",
"HAPP",
"HARP",
"HAS",
"HASI",
"HAYN",
"HAYW",
"HBAN",
"HBANM",
"HBANP",
"HBB",
"HBCP",
"HBI",
"HBIO",
"HBM",
"HBMD",
"HBNC",
"HBP",
"HBT",
"HCA",
"HCAQ",
"HCAR",
"HCARU",
"HCARW",
"HCAT",
"HCC",
"HCCC",
"HCCCW",
"HCCI",
"HCDI",
"HCDIP",
"HCDIW",
"HCDIZ",
"HCI",
"HCIC",
"HCICU",
"HCICW",
"HCII",
"HCIIW",
"HCKT",
"HCM",
"HCNE",
"HCNEU",
"HCNEW",
"HCSG",
"HCTI",
"HCVIU",
"HCWB",
"HCXY",
"HD",
"HDB",
"HDSN",
"HE",
"HEAR",
"HEES",
"HEI",
"HELE",
"HEP",
"HEPA",
"HEPS",
"HEQ",
"HERA",
"HERAU",
"HERAW",
"HES",
"HESM",
"HEXO",
"HFBL",
"HFC",
"HFFG",
"HFRO",
"HFWA",
"HGBL",
"HGEN",
"HGH",
"HGLB",
"HGSH",
"HGV",
"HHC",
"HHGCU",
"HHLA",
"HHR",
"HI",
"HIBB",
"HIE",
"HIFS",
"HIG",
"HIGA",
"HIHO",
"HII",
"HIII",
"HIIIU",
"HIIIW",
"HIL",
"HIMS",
"HIMX",
"HIO",
"HIPO",
"HITI",
"HIVE",
"HIW",
"HIX",
"HKIB",
"HL",
"HLAH",
"HLAHW",
"HLBZ",
"HLBZW",
"HLF",
"HLG",
"HLI",
"HLIO",
"HLIT",
"HLLY",
"HLMN",
"HLMNW",
"HLNE",
"HLT",
"HLTH",
"HLX",
"HLXA",
"HMC",
"HMCO",
"HMCOU",
"HMCOW",
"HMG",
"HMHC",
"HMLP",
"HMN",
"HMNF",
"HMPT",
"HMST",
"HMTV",
"HMY",
"HNGR",
"HNI",
"HNNA",
"HNNAZ",
"HNP",
"HNRG",
"HNST",
"HNW",
"HOFT",
"HOFV",
"HOFVW",
"HOG",
"HOLI",
"HOLX",
"HOMB",
"HON",
"HONE",
"HOOD",
"HOOK",
"HOPE",
"HOTH",
"HOV",
"HOVNP",
"HOWL",
"HP",
"HPE",
"HPF",
"HPI",
"HPK",
"HPKEW",
"HPLTU",
"HPP",
"HPQ",
"HPS",
"HPX",
"HQH",
"HQI",
"HQL",
"HQY",
"HR",
"HRB",
"HRC",
"HRI",
"HRL",
"HRMY",
"HROW",
"HROWL",
"HRT",
"HRTG",
"HRTX",
"HRZN",
"HSAQ",
"HSBC",
"HSC",
"HSDT",
"HSIC",
"HSII",
"HSKA",
"HSON",
"HST",
"HSTM",
"HSTO",
"HSY",
"HT",
"HTA",
"HTBI",
"HTBK",
"HTBX",
"HTD",
"HTGC",
"HTGM",
"HTH",
"HTHT",
"HTIA",
"HTIBP",
"HTLD",
"HTLF",
"HTLFP",
"HTOO",
"HTOOW",
"HTPA",
"HTY",
"HUBB",
"HUBG",
"HUBS",
"HUDI",
"HUGE",
"HUGS",
"HUIZ",
"HUM",
"HUMA",
"HUMAW",
"HUN",
"HURC",
"HURN",
"HUSA",
"HUSN",
"HUT",
"HUYA",
"HVBC",
"HVT",
"HWBK",
"HWC",
"HWCPZ",
"HWEL",
"HWELU",
"HWELW",
"HWKN",
"HWM",
"HX",
"HXL",
"HY",
"HYAC",
"HYACU",
"HYACW",
"HYB",
"HYFM",
"HYI",
"HYLN",
"HYMC",
"HYMCL",
"HYMCW",
"HYMCZ",
"HYRE",
"HYT",
"HYW",
"HYZN",
"HYZNW",
"HZN",
"HZNP",
"HZO",
"HZON",
"IAA",
"IAC",
"IACB",
"IACC",
"IAE",
"IAF",
"IAG",
"IART",
"IAS",
"IBA",
"IBCP",
"IBER",
"IBEX",
"IBIO",
"IBKR",
"IBM",
"IBN",
"IBOC",
"IBP",
"IBRX",
"IBTX",
"ICAD",
"ICBK",
"ICCC",
"ICCH",
"ICCM",
"ICD",
"ICE",
"ICFI",
"ICHR",
"ICL",
"ICLK",
"ICLR",
"ICMB",
"ICPT",
"ICUI",
"ICVX",
"ID",
"IDA",
"IDBA",
"IDCC",
"IDE",
"IDEX",
"IDN",
"IDRA",
"IDT",
"IDW",
"IDXX",
"IDYA",
"IEA",
"IEAWW",
"IEP",
"IESC",
"IEX",
"IFBD",
"IFF",
"IFMK",
"IFN",
"IFRX",
"IFS",
"IGA",
"IGAC",
"IGACU",
"IGACW",
"IGC",
"IGD",
"IGI",
"IGIC",
"IGICW",
"IGMS",
"IGNY",
"IGNYW",
"IGR",
"IGT",
"IH",
"IHC",
"IHD",
"IHG",
"IHIT",
"IHRT",
"IHS",
"IHT",
"IHTA",
"IIAC",
"IIF",
"III",
"IIII",
"IIIIU",
"IIIIW",
"IIIN",
"IIIV",
"IIM",
"IIN",
"IINN",
"IINNW",
"IIPR",
"IIVI",
"IIVIP",
"IKNA",
"IKNX",
"IKT",
"ILMN",
"ILPT",
"IMAB",
"IMAC",
"IMACW",
"IMAQ",
"IMAQR",
"IMAQU",
"IMAQW",
"IMAX",
"IMBI",
"IMBIL",
"IMCC",
"IMCR",
"IMGN",
"IMGO",
"IMH",
"IMKTA",
"IMMP",
"IMMR",
"IMNM",
"IMO",
"IMOS",
"IMPL",
"IMPX",
"IMRA",
"IMRN",
"IMRNW",
"IMRX",
"IMTE",
"IMTX",
"IMTXW",
"IMUX",
"IMV",
"IMVT",
"IMXI",
"INAB",
"INAQ",
"INBK",
"INBKZ",
"INBX",
"INCR",
"INCY",
"INDB",
"INDI",
"INDIW",
"INDO",
"INDP",
"INDT",
"INFA",
"INFI",
"INFN",
"INFO",
"INFU",
"INFY",
"ING",
"INGN",
"INGR",
"INKA",
"INKAU",
"INKAW",
"INKT",
"INM",
"INMB",
"INMD",
"INN",
"INNV",
"INO",
"INOD",
"INOV",
"INPX",
"INS",
"INSE",
"INSG",
"INSI",
"INSM",
"INSP",
"INST",
"INSW",
"INT",
"INTA",
"INTC",
"INTEU",
"INTG",
"INTT",
"INTU",
"INTZ",
"INUV",
"INVA",
"INVE",
"INVH",
"INVO",
"INVZ",
"INVZW",
"INZY",
"IO",
"IOACU",
"IOBT",
"IONM",
"IONQ",
"IONS",
"IOR",
"IOSP",
"IOVA",
"IP",
"IPA",
"IPAR",
"IPAXU",
"IPDN",
"IPG",
"IPGP",
"IPHA",
"IPI",
"IPLDP",
"IPOD",
"IPOF",
"IPSC",
"IPVA",
"IPVF",
"IPVI",
"IPVIU",
"IPW",
"IPWR",
"IQ",
"IQI",
"IQMDU",
"IQV",
"IR",
"IRBT",
"IRCP",
"IRDM",
"IRIX",
"IRL",
"IRM",
"IRMD",
"IRNT",
"IROQ",
"IRS",
"IRT",
"IRTC",
"IRWD",
"IS",
"ISAA",
"ISBC",
"ISD",
"ISDR",
"ISEE",
"ISIG",
"ISLE",
"ISLEW",
"ISO",
"ISOS",
"ISPC",
"ISR",
"ISRG",
"ISSC",
"ISTR",
"ISUN",
"IT",
"ITCB",
"ITCI",
"ITGR",
"ITHX",
"ITHXU",
"ITHXW",
"ITI",
"ITIC",
"ITMR",
"ITOS",
"ITP",
"ITQ",
"ITQRW",
"ITRG",
"ITRI",
"ITRM",
"ITRN",
"ITT",
"ITUB",
"ITW",
"IVA",
"IVAC",
"IVAN",
"IVC",
"IVH",
"IVR",
"IVT",
"IVZ",
"IX",
"IXAQU",
"IZEA",
"J",
"JACK",
"JAGX",
"JAKK",
"JAMF",
"JAN",
"JANX",
"JAQC",
"JAQCU",
"JAQCW",
"JATT",
"JAZZ",
"JBGS",
"JBHT",
"JBI",
"JBK",
"JBL",
"JBLU",
"JBSS",
"JBT",
"JCE",
"JCI",
"JCIC",
"JCICU",
"JCICW",
"JCO",
"JCS",
"JCTCF",
"JD",
"JDD",
"JEF",
"JELD",
"JEMD",
"JEQ",
"JFIN",
"JFR",
"JFU",
"JG",
"JGH",
"JHAA",
"JHG",
"JHI",
"JHS",
"JHX",
"JILL",
"JJSF",
"JKHY",
"JKS",
"JLL",
"JLS",
"JMACU",
"JMIA",
"JMM",
"JMP",
"JMPNZ",
"JNCE",
"JNJ",
"JNPR",
"JOAN",
"JOB",
"JOBS",
"JOBY",
"JOE",
"JOF",
"JOFF",
"JOFFU",
"JOFFW",
"JOUT",
"JP",
"JPC",
"JPI",
"JPM",
"JPS",
"JPT",
"JQC",
"JRI",
"JRJC",
"JRO",
"JRS",
"JRSH",
"JRVR",
"JSD",
"JSM",
"JSPR",
"JSPRW",
"JT",
"JTA",
"JTD",
"JUGG",
"JUGGU",
"JUGGW",
"JUPW",
"JUPWW",
"JVA",
"JWEL",
"JWN",
"JWSM",
"JXN",
"JYAC",
"JYNT",
"JZXN",
"K",
"KAHC",
"KAI",
"KAII",
"KAIIU",
"KAIIW",
"KAIR",
"KAIRU",
"KAIRW",
"KALA",
"KALU",
"KALV",
"KAMN",
"KAR",
"KARO",
"KAVL",
"KB",
"KBAL",
"KBH",
"KBNT",
"KBNTW",
"KBR",
"KC",
"KCGI",
"KD",
"KDMN",
"KDNY",
"KDP",
"KE",
"KELYA",
"KELYB",
"KEN",
"KEP",
"KEQU",
"KERN",
"KERNW",
"KEX",
"KEY",
"KEYS",
"KF",
"KFFB",
"KFRC",
"KFS",
"KFY",
"KGC",
"KHC",
"KIDS",
"KIII",
"KIIIU",
"KIIIW",
"KIM",
"KIND",
"KINS",
"KINZ",
"KINZW",
"KIO",
"KIQ",
"KIRK",
"KKR",
"KKRS",
"KL",
"KLAC",
"KLDO",
"KLIC",
"KLR",
"KLTR",
"KLXE",
"KMB",
"KMDA",
"KMF",
"KMI",
"KMPH",
"KMPR",
"KMT",
"KMX",
"KN",
"KNBE",
"KNDI",
"KNOP",
"KNSA",
"KNSL",
"KNTE",
"KNX",
"KO",
"KOD",
"KODK",
"KOF",
"KOP",
"KOPN",
"KOR",
"KORE",
"KOS",
"KOSS",
"KPLT",
"KPLTW",
"KPRX",
"KPTI",
"KR",
"KRA",
"KRBP",
"KRC",
"KREF",
"KRG",
"KRKR",
"KRMD",
"KRNL",
"KRNLW",
"KRNT",
"KRNY",
"KRO",
"KRON",
"KROS",
"KRP",
"KRT",
"KRTX",
"KRUS",
"KRYS",
"KSI",
"KSICU",
"KSICW",
"KSM",
"KSPN",
"KSS",
"KSU",
"KT",
"KTB",
"KTCC",
"KTF",
"KTH",
"KTN",
"KTOS",
"KTRA",
"KTTA",
"KTTAW",
"KUKE",
"KULR",
"KURA",
"KVHI",
"KVSA",
"KVSC",
"KW",
"KWAC",
"KWR",
"KXIN",
"KYMR",
"KYN",
"KZIA",
"KZR",
"L",
"LAAA",
"LABP",
"LAC",
"LAD",
"LADR",
"LAIX",
"LAKE",
"LAMR",
"LANC",
"LAND",
"LANDM",
"LANDO",
"LARK",
"LASR",
"LAUR",
"LAW",
"LAWS",
"LAZ",
"LAZR",
"LAZY",
"LBAI",
"LBC",
"LBPH",
"LBPS",
"LBPSW",
"LBRDA",
"LBRDK",
"LBRDP",
"LBRT",
"LBTYA",
"LBTYB",
"LBTYK",
"LC",
"LCA",
"LCAA",
"LCAAU",
"LCAAW",
"LCAHU",
"LCAHW",
"LCAP",
"LCAPU",
"LCAPW",
"LCI",
"LCID",
"LCII",
"LCNB",
"LCTX",
"LCUT",
"LDHA",
"LDHAU",
"LDHAW",
"LDI",
"LDOS",
"LDP",
"LE",
"LEA",
"LEAP",
"LECO",
"LEDS",
"LEE",
"LEG",
"LEGA",
"LEGAU",
"LEGAW",
"LEGH",
"LEGN",
"LEJU",
"LEN",
"LEO",
"LESL",
"LEU",
"LEV",
"LEVI",
"LEVL",
"LEVLP",
"LEXX",
"LEXXW",
"LFC",
"LFG",
"LFMD",
"LFMDP",
"LFST",
"LFT",
"LFTR",
"LFTRU",
"LFTRW",
"LFUS",
"LFVN",
"LGAC",
"LGACU",
"LGACW",
"LGHL",
"LGHLW",
"LGI",
"LGIH",
"LGL",
"LGND",
"LGO",
"LGSTU",
"LGV",
"LGVN",
"LH",
"LHAA",
"LHC",
"LHCG",
"LHDX",
"LHX",
"LI",
"LIAN",
"LIBYU",
"LICY",
"LIDR",
"LIDRW",
"LIFE",
"LII",
"LIII",
"LILA",
"LILAK",
"LILM",
"LILMW",
"LIN",
"LINC",
"LIND",
"LINK",
"LIONU",
"LIQT",
"LITB",
"LITE",
"LITT",
"LITTU",
"LITTW",
"LIVE",
"LIVN",
"LIXT",
"LIXTW",
"LIZI",
"LJAQ",
"LJAQU",
"LJAQW",
"LJPC",
"LKCO",
"LKFN",
"LKQ",
"LL",
"LLL",
"LLNW",
"LLY",
"LMACA",
"LMACU",
"LMACW",
"LMAO",
"LMAOU",
"LMAOW",
"LMAT",
"LMB",
"LMDX",
"LMDXW",
"LMFA",
"LMND",
"LMNL",
"LMNR",
"LMPX",
"LMRK",
"LMRKN",
"LMRKO",
"LMRKP",
"LMST",
"LMT",
"LNC",
"LND",
"LNDC",
"LNFA",
"LNG",
"LNN",
"LNSR",
"LNT",
"LNTH",
"LOAN",
"LOB",
"LOCO",
"LODE",
"LOGC",
"LOGI",
"LOKM",
"LOMA",
"LOOP",
"LOPE",
"LORL",
"LOTZ",
"LOTZW",
"LOV",
"LOVE",
"LOW",
"LPCN",
"LPG",
"LPI",
"LPL",
"LPLA",
"LPRO",
"LPSN",
"LPTH",
"LPTX",
"LPX",
"LQDA",
"LQDT",
"LRCX",
"LRFC",
"LRMR",
"LRN",
"LSBK",
"LSCC",
"LSEA",
"LSEAW",
"LSF",
"LSI",
"LSPD",
"LSTR",
"LSXMA",
"LSXMB",
"LSXMK",
"LTBR",
"LTC",
"LTCH",
"LTCHW",
"LTH",
"LTHM",
"LTRN",
"LTRPA",
"LTRPB",
"LTRX",
"LTRY",
"LTRYW",
"LU",
"LUB",
"LUCD",
"LULU",
"LUMN",
"LUMO",
"LUNA",
"LUNG",
"LUV",
"LUXA",
"LUXAU",
"LUXAW",
"LVACU",
"LVO",
"LVOX",
"LVOXW",
"LVRA",
"LVRAW",
"LVS",
"LVTX",
"LW",
"LWAY",
"LWLG",
"LX",
"LXEH",
"LXFR",
"LXP",
"LXRX",
"LXU",
"LYB",
"LYEL",
"LYFT",
"LYG",
"LYL",
"LYLT",
"LYRA",
"LYTS",
"LYV",
"LZ",
"LZB",
"M",
"MA",
"MAA",
"MAC",
"MACA",
"MACAU",
"MACAW",
"MACC",
"MACK",
"MACQ",
"MACQU",
"MACQW",
"MACU",
"MACUW",
"MAG",
"MAIN",
"MAN",
"MANH",
"MANT",
"MANU",
"MAPS",
"MAPSW",
"MAQC",
"MAQCW",
"MAR",
"MARA",
"MARK",
"MARPS",
"MAS",
"MASI",
"MASS",
"MAT",
"MATW",
"MATX",
"MAV",
"MAX",
"MAXN",
"MAXR",
"MAYS",
"MBAC",
"MBCN",
"MBI",
"MBII",
"MBIN",
"MBINN",
"MBINO",
"MBINP",
"MBIO",
"MBNKP",
"MBOT",
"MBRX",
"MBT",
"MBTC",
"MBTCR",
"MBTCU",
"MBUU",
"MBWM",
"MC",
"MCA",
"MCAAU",
"MCAE",
"MCAER",
"MCAF",
"MCAFR",
"MCB",
"MCBC",
"MCBS",
"MCD",
"MCF",
"MCFE",
"MCFT",
"MCG",
"MCHP",
"MCHX",
"MCI",
"MCK",
"MCMJ",
"MCMJW",
"MCN",
"MCO",
"MCR",
"MCRB",
"MCRI",
"MCS",
"MCW",
"MCY",
"MD",
"MDB",
"MDC",
"MDGL",
"MDGS",
"MDGSW",
"MDH",
"MDIA",
"MDJH",
"MDLZ",
"MDNA",
"MDP",
"MDRR",
"MDRRP",
"MDRX",
"MDT",
"MDU",
"MDVA",
"MDVL",
"MDWD",
"MDWT",
"MDXG",
"MDXH",
"ME",
"MEAC",
"MEACU",
"MEACW",
"MEC",
"MED",
"MEDP",
"MEDS",
"MEG",
"MEGI",
"MEI",
"MEIP",
"MEKA",
"MELI",
"MEOA",
"MEOAU",
"MEOAW",
"MEOH",
"MERC",
"MESA",
"MESO",
"MET",
"METC",
"METCL",
"METX",
"METXW",
"MEUSW",
"MF",
"MFA",
"MFC",
"MFD",
"MFG",
"MFGP",
"MFH",
"MFIN",
"MFL",
"MFM",
"MFV",
"MG",
"MGA",
"MGEE",
"MGF",
"MGI",
"MGIC",
"MGLN",
"MGM",
"MGNI",
"MGNX",
"MGP",
"MGPI",
"MGR",
"MGRB",
"MGRC",
"MGRD",
"MGTA",
"MGTX",
"MGU",
"MGY",
"MGYR",
"MHD",
"MHF",
"MHH",
"MHI",
"MHK",
"MHLA",
"MHLD",
"MHN",
"MHNC",
"MHO",
"MIC",
"MICT",
"MIDD",
"MIGI",
"MILE",
"MILEW",
"MIME",
"MIMO",
"MIN",
"MIND",
"MINDP",
"MINM",
"MIO",
"MIR",
"MIRM",
"MIRO",
"MIST",
"MIT",
"MITA",
"MITAU",
"MITAW",
"MITC",
"MITK",
"MITO",
"MITQ",
"MITT",
"MIXT",
"MIY",
"MKC",
"MKD",
"MKFG",
"MKL",
"MKSI",
"MKTW",
"MKTWW",
"MKTX",
"ML",
"MLAB",
"MLAC",
"MLACW",
"MLAIU",
"MLCO",
"MLI",
"MLKN",
"MLM",
"MLNK",
"MLP",
"MLR",
"MLSS",
"MLVF",
"MMAT",
"MMC",
"MMD",
"MMI",
"MMLP",
"MMM",
"MMMB",
"MMP",
"MMS",
"MMSI",
"MMT",
"MMU",
"MMX",
"MMYT",
"MN",
"MNDO",
"MNDT",
"MNDY",
"MNKD",
"MNMD",
"MNOV",
"MNP",
"MNPR",
"MNR",
"MNRL",
"MNRO",
"MNSB",
"MNSBP",
"MNSO",
"MNST",
"MNTK",
"MNTS",
"MNTSW",
"MNTV",
"MNTX",
"MO",
"MOD",
"MODN",
"MODV",
"MOFG",
"MOGO",
"MOGU",
"MOH",
"MOHO",
"MOLN",
"MOMO",
"MON",
"MONCU",
"MONCW",
"MOR",
"MORF",
"MORN",
"MOS",
"MOSY",
"MOTS",
"MOTV",
"MOV",
"MOVE",
"MOXC",
"MP",
"MPA",
"MPAA",
"MPAC",
"MPACR",
"MPACW",
"MPB",
"MPC",
"MPLN",
"MPLX",
"MPRAU",
"MPV",
"MPW",
"MPWR",
"MPX",
"MQ",
"MQT",
"MQY",
"MRAI",
"MRAM",
"MRBK",
"MRC",
"MRCC",
"MRCY",
"MREO",
"MRIN",
"MRK",
"MRKR",
"MRLN",
"MRM",
"MRNA",
"MRNS",
"MRO",
"MRSN",
"MRTN",
"MRTX",
"MRUS",
"MRVI",
"MRVL",
"MS",
"MSA",
"MSAC",
"MSACW",
"MSB",
"MSBI",
"MSC",
"MSCI",
"MSD",
"MSDA",
"MSDAU",
"MSDAW",
"MSEX",
"MSFT",
"MSGE",
"MSGM",
"MSGS",
"MSI",
"MSM",
"MSN",
"MSP",
"MSTR",
"MSVB",
"MT",
"MTA",
"MTAC",
"MTACU",
"MTACW",
"MTAL",
"MTB",
"MTBC",
"MTBCP",
"MTC",
"MTCH",
"MTCN",
"MTCR",
"MTD",
"MTDR",
"MTEM",
"MTEX",
"MTG",
"MTH",
"MTL",
"MTLS",
"MTN",
"MTNB",
"MTOR",
"MTP",
"MTR",
"MTRN",
"MTRX",
"MTRYU",
"MTSI",
"MTTR",
"MTTRW",
"MTW",
"MTX",
"MTZ",
"MU",
"MUA",
"MUC",
"MUDS",
"MUDSU",
"MUDSW",
"MUE",
"MUFG",
"MUI",
"MUJ",
"MULN",
"MUR",
"MUSA",
"MUX",
"MVBF",
"MVF",
"MVIS",
"MVO",
"MVST",
"MVSTW",
"MVT",
"MWA",
"MX",
"MXC",
"MXCT",
"MXE",
"MXF",
"MXL",
"MYC",
"MYD",
"MYE",
"MYFW",
"MYGN",
"MYI",
"MYJ",
"MYMD",
"MYN",
"MYNZ",
"MYO",
"MYOV",
"MYPS",
"MYPSW",
"MYRG",
"MYSZ",
"MYTE",
"NAAC",
"NAACU",
"NAACW",
"NABL",
"NAC",
"NAD",
"NAII",
"NAK",
"NAKD",
"NAN",
"NAOV",
"NAPA",
"NARI",
"NAT",
"NATH",
"NATI",
"NATR",
"NAUT",
"NAVB",
"NAVI",
"NAZ",
"NBB",
"NBEV",
"NBH",
"NBHC",
"NBIX",
"NBN",
"NBO",
"NBR",
"NBRV",
"NBSE",
"NBST",
"NBSTU",
"NBSTW",
"NBTB",
"NBTX",
"NBW",
"NBXG",
"NBY",
"NC",
"NCA",
"NCACU",
"NCBS",
"NCLH",
"NCMI",
"NCNA",
"NCNO",
"NCR",
"NCSM",
"NCTY",
"NCV",
"NCZ",
"NDAC",
"NDACU",
"NDACW",
"NDAQ",
"NDLS",
"NDMO",
"NDP",
"NDRA",
"NDRAW",
"NDSN",
"NE",
"NEA",
"NECB",
"NEE",
"NEGG",
"NEM",
"NEN",
"NEO",
"NEOG",
"NEON",
"NEP",
"NEPH",
"NEPT",
"NERV",
"NES",
"NESR",
"NESRW",
"NET",
"NETI",
"NEU",
"NEV",
"NEW",
"NEWP",
"NEWR",
"NEWT",
"NEWTL",
"NEWTZ",
"NEX",
"NEXA",
"NEXI",
"NEXT",
"NFBK",
"NFE",
"NFG",
"NFGC",
"NFH",
"NFJ",
"NFLX",
"NG",
"NGAB",
"NGC",
"NGCA",
"NGCAU",
"NGCAW",
"NGD",
"NGG",
"NGL",
"NGM",
"NGMS",
"NGS",
"NGVC",
"NGVT",
"NH",
"NHC",
"NHI",
"NHICU",
"NHS",
"NHTC",
"NI",
"NICE",
"NICK",
"NID",
"NIE",
"NIM",
"NIMC",
"NINE",
"NIO",
"NIQ",
"NISN",
"NIU",
"NJR",
"NKE",
"NKG",
"NKLA",
"NKSH",
"NKTR",
"NKTX",
"NKX",
"NL",
"NLIT",
"NLITW",
"NLOK",
"NLS",
"NLSN",
"NLSP",
"NLSPW",
"NLTX",
"NLY",
"NM",
"NMCO",
"NMFC",
"NMG",
"NMI",
"NMIH",
"NML",
"NMM",
"NMMC",
"NMMCU",
"NMMCW",
"NMR",
"NMRD",
"NMRK",
"NMS",
"NMT",
"NMTC",
"NMTR",
"NMZ",
"NN",
"NNAVW",
"NNBR",
"NNDM",
"NNI",
"NNN",
"NNOX",
"NNVC",
"NNY",
"NOA",
"NOAC",
"NOACU",
"NOACW",
"NOAH",
"NOC",
"NODK",
"NOG",
"NOK",
"NOMD",
"NOTV",
"NOV",
"NOVA",
"NOVN",
"NOVT",
"NOVV",
"NOVVR",
"NOVVU",
"NOVVW",
"NOW",
"NP",
"NPABU",
"NPCE",
"NPCT",
"NPK",
"NPO",
"NPTN",
"NPV",
"NQP",
"NR",
"NRAC",
"NRACU",
"NRACW",
"NRBO",
"NRC",
"NRDS",
"NRDY",
"NREF",
"NRG",
"NRGX",
"NRIM",
"NRIX",
"NRK",
"NRO",
"NRP",
"NRT",
"NRUC",
"NRXP",
"NRXPW",
"NRZ",
"NS",
"NSA",
"NSC",
"NSEC",
"NSIT",
"NSL",
"NSP",
"NSPR",
"NSPRZ",
"NSR",
"NSS",
"NSSC",
"NSTB",
"NSTD",
"NSTG",
"NSYS",
"NTAP",
"NTB",
"NTCO",
"NTCT",
"NTES",
"NTG",
"NTGR",
"NTIC",
"NTIP",
"NTLA",
"NTNX",
"NTP",
"NTR",
"NTRA",
"NTRB",
"NTRBW",
"NTRS",
"NTRSO",
"NTST",
"NTUS",
"NTWK",
"NTZ",
"NUAN",
"NUE",
"NUO",
"NURO",
"NUS",
"NUV",
"NUVA",
"NUVB",
"NUVL",
"NUW",
"NUWE",
"NUZE",
"NVAX",
"NVCN",
"NVCR",
"NVDA",
"NVEC",
"NVEE",
"NVEI",
"NVFY",
"NVG",
"NVGS",
"NVIV",
"NVMI",
"NVNO",
"NVNOW",
"NVO",
"NVOS",
"NVR",
"NVRO",
"NVS",
"NVSA",
"NVSAU",
"NVSAW",
"NVST",
"NVT",
"NVTA",
"NVTS",
"NVTSW",
"NVVE",
"NVVEW",
"NWBI",
"NWE",
"NWFL",
"NWG",
"NWL",
"NWLI",
"NWN",
"NWPX",
"NWS",
"NWSA",
"NX",
"NXC",
"NXDT",
"NXE",
"NXGN",
"NXJ",
"NXN",
"NXP",
"NXPI",
"NXQ",
"NXR",
"NXRT",
"NXST",
"NXTC",
"NXTD",
"NXTP",
"NXU",
"NYC",
"NYCB",
"NYMT",
"NYMTL",
"NYMTM",
"NYMTN",
"NYMTP",
"NYMX",
"NYT",
"NYXH",
"NZF",
"O",
"OACB",
"OAS",
"OB",
"OBAS",
"OBCI",
"OBLG",
"OBNK",
"OBSV",
"OBT",
"OC",
"OCA",
"OCAX",
"OCAXU",
"OCC",
"OCCI",
"OCCIO",
"OCCIP",
"OCDX",
"OCFC",
"OCFCP",
"OCFT",
"OCG",
"OCGN",
"OCN",
"OCSL",
"OCUL",
"OCUP",
"OCX",
"ODC",
"ODFL",
"ODP",
"ODT",
"OEC",
"OEG",
"OEPW",
"OEPWU",
"OEPWW",
"OESX",
"OFC",
"OFED",
"OFG",
"OFIX",
"OFLX",
"OFS",
"OFSSH",
"OFSSI",
"OG",
"OGE",
"OGEN",
"OGI",
"OGN",
"OGS",
"OHAAU",
"OHI",
"OHPA",
"OHPAU",
"OHPAW",
"OI",
"OIA",
"OII",
"OIIM",
"OIS",
"OKE",
"OKTA",
"OLB",
"OLED",
"OLK",
"OLLI",
"OLMA",
"OLN",
"OLO",
"OLP",
"OLPX",
"OM",
"OMAB",
"OMC",
"OMCL",
"OMEG",
"OMER",
"OMEX",
"OMF",
"OMGA",
"OMI",
"OMIC",
"OMP",
"OMQS",
"ON",
"ONB",
"ONCR",
"ONCS",
"ONCT",
"ONCY",
"ONDS",
"ONEM",
"ONEW",
"ONON",
"ONTF",
"ONTO",
"ONTX",
"ONVO",
"ONYXU",
"OOMA",
"OPA",
"OPAD",
"OPBK",
"OPCH",
"OPEN",
"OPFI",
"OPGN",
"OPHC",
"OPI",
"OPINL",
"OPK",
"OPNT",
"OPOF",
"OPP",
"OPRA",
"OPRT",
"OPRX",
"OPT",
"OPTN",
"OPTT",
"OPY",
"OR",
"ORA",
"ORAN",
"ORC",
"ORCC",
"ORCL",
"ORGN",
"ORGNW",
"ORGO",
"ORGS",
"ORI",
"ORIA",
"ORIC",
"ORLA",
"ORLY",
"ORMP",
"ORN",
"ORPH",
"ORRF",
"ORTX",
"OSAT",
"OSATW",
"OSBC",
"OSCR",
"OSG",
"OSH",
"OSI",
"OSIS",
"OSK",
"OSMT",
"OSPN",
"OSS",
"OSTK",
"OSTR",
"OSTRW",
"OSUR",
"OSW",
"OTEC",
"OTECW",
"OTEX",
"OTIC",
"OTIS",
"OTLK",
"OTLKW",
"OTLY",
"OTMO",
"OTMOW",
"OTRA",
"OTRAW",
"OTRK",
"OTRKP",
"OTTR",
"OUST",
"OUT",
"OVBC",
"OVID",
"OVLY",
"OVV",
"OWL",
"OWLT",
"OXAC",
"OXACU",
"OXACW",
"OXBR",
"OXBRW",
"OXLC",
"OXLCL",
"OXLCM",
"OXLCO",
"OXLCP",
"OXM",
"OXSQ",
"OXSQG",
"OXSQL",
"OXSQZ",
"OXUS",
"OXUSU",
"OXUSW",
"OXY",
"OYST",
"OZ",
"OZK",
"OZKAP",
"OZON",
"PAA",
"PAAS",
"PAC",
"PACB",
"PACK",
"PACW",
"PACX",
"PACXU",
"PACXW",
"PAE",
"PAEWW",
"PAFO",
"PAFOR",
"PAFOU",
"PAG",
"PAGP",
"PAGS",
"PAHC",
"PAI",
"PAIC",
"PAICW",
"PALI",
"PALT",
"PAM",
"PANA",
"PANL",
"PANW",
"PAQC",
"PAQCU",
"PAQCW",
"PAR",
"PARR",
"PASG",
"PATH",
"PATI",
"PATK",
"PAVM",
"PAVMW",
"PAVMZ",
"PAX",
"PAY",
"PAYA",
"PAYC",
"PAYO",
"PAYOW",
"PAYS",
"PAYX",
"PB",
"PBA",
"PBAXU",
"PBBK",
"PBC",
"PBCT",
"PBCTP",
"PBF",
"PBFS",
"PBFX",
"PBH",
"PBHC",
"PBI",
"PBIP",
"PBLA",
"PBPB",
"PBR",
"PBT",
"PBTS",
"PBYI",
"PCAR",
"PCB",
"PCCTU",
"PCF",
"PCG",
"PCGU",
"PCH",
"PCI",
"PCK",
"PCM",
"PCN",
"PCOM",
"PCOR",
"PCPC",
"PCQ",
"PCRX",
"PCSA",
"PCSB",
"PCT",
"PCTI",
"PCTTU",
"PCTTW",
"PCTY",
"PCVX",
"PCXCU",
"PCYG",
"PCYO",
"PD",
"PDCE",
"PDCO",
"PDD",
"PDEX",
"PDFS",
"PDI",
"PDLB",
"PDM",
"PDO",
"PDOT",
"PDS",
"PDSB",
"PDT",
"PEAK",
"PEB",
"PEBK",
"PEBO",
"PECO",
"PED",
"PEG",
"PEGA",
"PEGRU",
"PEI",
"PEN",
"PENN",
"PEO",
"PEP",
"PEPLU",
"PERI",
"PESI",
"PETQ",
"PETS",
"PETV",
"PETVW",
"PETZ",
"PFBC",
"PFC",
"PFD",
"PFDR",
"PFDRU",
"PFDRW",
"PFE",
"PFG",
"PFGC",
"PFH",
"PFHD",
"PFIE",
"PFIN",
"PFIS",
"PFL",
"PFLT",
"PFMT",
"PFN",
"PFO",
"PFS",
"PFSI",
"PFSW",
"PFTA",
"PFTAU",
"PFTAW",
"PFX",
"PFXNL",
"PG",
"PGC",
"PGEN",
"PGNY",
"PGP",
"PGR",
"PGRE",
"PGRW",
"PGRWW",
"PGTI",
"PGZ",
"PH",
"PHAR",
"PHAS",
"PHAT",
"PHCF",
"PHD",
"PHG",
"PHGE",
"PHI",
"PHIC",
"PHICU",
"PHIO",
"PHIOW",
"PHK",
"PHM",
"PHR",
"PHT",
"PHUN",
"PHUNW",
"PHVS",
"PHX",
"PI",
"PIAI",
"PICC",
"PII",
"PIM",
"PINC",
"PINE",
"PING",
"PINS",
"PIPP",
"PIPR",
"PIRS",
"PIXY",
"PJT",
"PK",
"PKBK",
"PKE",
"PKG",
"PKI",
"PKO",
"PKOH",
"PKX",
"PLAB",
"PLAG",
"PLAN",
"PLAY",
"PLBC",
"PLBY",
"PLCE",
"PLD",
"PLG",
"PLIN",
"PLL",
"PLM",
"PLMI",
"PLMIU",
"PLMIW",
"PLMR",
"PLNT",
"PLOW",
"PLPC",
"PLRX",
"PLSE",
"PLTK",
"PLTR",
"PLUG",
"PLUS",
"PLX",
"PLXP",
"PLXS",
"PLYA",
"PLYM",
"PM",
"PMCB",
"PMD",
"PME",
"PMF",
"PMGM",
"PMGMU",
"PMGMW",
"PML",
"PMM",
"PMO",
"PMT",
"PMTS",
"PMVC",
"PMVP",
"PMX",
"PNBK",
"PNC",
"PNF",
"PNFP",
"PNFPP",
"PNI",
"PNM",
"PNNT",
"PNNTG",
"PNR",
"PNRG",
"PNT",
"PNTG",
"PNTM",
"PNW",
"POAI",
"PODD",
"POLA",
"POLY",
"POND",
"PONO",
"PONOW",
"POOL",
"POR",
"POSH",
"POST",
"POW",
"POWI",
"POWL",
"POWRU",
"POWRW",
"POWW",
"POWWP",
"PPBI",
"PPBT",
"PPC",
"PPD",
"PPG",
"PPGH",
"PPGHU",
"PPGHW",
"PPHP",
"PPHPR",
"PPHPU",
"PPHPW",
"PPIH",
"PPL",
"PPSI",
"PPT",
"PPTA",
"PRA",
"PRAA",
"PRAX",
"PRBM",
"PRCH",
"PRCT",
"PRDO",
"PRFT",
"PRFX",
"PRG",
"PRGO",
"PRGS",
"PRI",
"PRIM",
"PRK",
"PRLB",
"PRLD",
"PRMW",
"PRO",
"PROC",
"PROCW",
"PROF",
"PROG",
"PROV",
"PRPB",
"PRPC",
"PRPH",
"PRPL",
"PRPO",
"PRQR",
"PRS",
"PRSR",
"PRSRU",
"PRSRW",
"PRT",
"PRTA",
"PRTC",
"PRTG",
"PRTH",
"PRTK",
"PRTS",
"PRTY",
"PRU",
"PRVA",
"PRVB",
"PSA",
"PSAG",
"PSAGU",
"PSAGW",
"PSB",
"PSEC",
"PSF",
"PSFE",
"PSHG",
"PSMT",
"PSN",
"PSNL",
"PSO",
"PSPC",
"PSTG",
"PSTH",
"PSTI",
"PSTL",
"PSTV",
"PSTX",
"PSX",
"PSXP",
"PT",
"PTA",
"PTC",
"PTCT",
"PTE",
"PTEN",
"PTGX",
"PTIC",
"PTICU",
"PTICW",
"PTIX",
"PTIXW",
"PTLO",
"PTMN",
"PTN",
"PTNR",
"PTOC",
"PTOCU",
"PTOCW",
"PTON",
"PTPI",
"PTR",
"PTRA",
"PTRS",
"PTSI",
"PTVE",
"PTY",
"PUBM",
"PUCK",
"PUCKU",
"PUCKW",
"PUK",
"PULM",
"PUMP",
"PUYI",
"PV",
"PVBC",
"PVG",
"PVH",
"PVL",
"PW",
"PWFL",
"PWOD",
"PWP",
"PWPPW",
"PWR",
"PWSC",
"PX",
"PXD",
"PXLW",
"PXS",
"PXSAP",
"PXSAW",
"PYCR",
"PYN",
"PYPD",
"PYPL",
"PYR",
"PYS",
"PYT",
"PYXS",
"PZC",
"PZG",
"PZN",
"PZZA",
"QCOM",
"QCRH",
"QD",
"QDEL",
"QFIN",
"QFTA",
"QGEN",
"QH",
"QIPT",
"QIWI",
"QK",
"QLGN",
"QLI",
"QLYS",
"QMCO",
"QNRX",
"QNST",
"QQQX",
"QRHC",
"QRTEA",
"QRTEB",
"QRTEP",
"QRVO",
"QS",
"QSI",
"QSIAW",
"QSR",
"QTNT",
"QTRX",
"QTT",
"QTWO",
"QUAD",
"QUBT",
"QUIK",
"QUMU",
"QUOT",
"QURE",
"QVCC",
"QVCD",
"R",
"RA",
"RAAS",
"RACB",
"RACE",
"RAD",
"RADA",
"RADI",
"RAIL",
"RAIN",
"RAM",
"RAMMU",
"RAMMW",
"RAMP",
"RAND",
"RANI",
"RAPT",
"RARE",
"RAVE",
"RAVN",
"RBA",
"RBAC",
"RBB",
"RBBN",
"RBCAA",
"RBCN",
"RBKB",
"RBLX",
"RBNC",
"RBOT",
"RC",
"RCA",
"RCAT",
"RCB",
"RCC",
"RCEL",
"RCG",
"RCHG",
"RCHGU",
"RCHGW",
"RCI",
"RCII",
"RCKT",
"RCKY",
"RCL",
"RCLF",
"RCLFU",
"RCLFW",
"RCM",
"RCMT",
"RCON",
"RCOR",
"RCRT",
"RCRTW",
"RCS",
"RCUS",
"RDBX",
"RDBXW",
"RDCM",
"RDFN",
"RDHL",
"RDI",
"RDIB",
"RDN",
"RDNT",
"RDUS",
"RDVT",
"RDW",
"RDWR",
"RDY",
"RE",
"REAL",
"REAX",
"REDU",
"REE",
"REEAW",
"REED",
"REFR",
"REG",
"REGI",
"REGN",
"REI",
"REKR",
"RELI",
"RELIW",
"RELL",
"RELX",
"RELY",
"RENN",
"RENT",
"REPH",
"REPL",
"REPX",
"RERE",
"RES",
"RESN",
"RETA",
"RETO",
"REV",
"REVE",
"REVEU",
"REVEW",
"REVG",
"REVH",
"REVHU",
"REVHW",
"REX",
"REXR",
"REYN",
"REZI",
"RF",
"RFI",
"RFIL",
"RFL",
"RFM",
"RFMZ",
"RFP",
"RGA",
"RGC",
"RGCO",
"RGEN",
"RGF",
"RGLD",
"RGLS",
"RGNX",
"RGP",
"RGR",
"RGS",
"RGT",
"RH",
"RHE",
"RHI",
"RHP",
"RIBT",
"RICK",
"RICOW",
"RIDE",
"RIG",
"RIGL",
"RILY",
"RILYK",
"RILYL",
"RILYM",
"RILYN",
"RILYO",
"RILYP",
"RILYT",
"RILYZ",
"RIO",
"RIOT",
"RIV",
"RIVE",
"RJF",
"RKDA",
"RKLB",
"RKLBW",
"RKLY",
"RKT",
"RKTA",
"RL",
"RLAY",
"RLGT",
"RLGY",
"RLI",
"RLJ",
"RLMD",
"RLX",
"RLYB",
"RM",
"RMAX",
"RMBI",
"RMBL",
"RMBS",
"RMCF",
"RMD",
"RMED",
"RMGC",
"RMGCU",
"RMGCW",
"RMI",
"RMM",
"RMNI",
"RMO",
"RMR",
"RMT",
"RMTI",
"RNA",
"RNAZ",
"RNDB",
"RNERU",
"RNG",
"RNGR",
"RNLX",
"RNP",
"RNR",
"RNST",
"RNW",
"RNWK",
"RNWWW",
"RNXT",
"ROAD",
"ROCC",
"ROCG",
"ROCGU",
"ROCGW",
"ROCK",
"ROCR",
"ROCRU",
"ROCRW",
"ROG",
"ROIC",
"ROIV",
"ROIVW",
"ROK",
"ROKU",
"ROL",
"ROLL",
"ROLLP",
"RONI",
"ROOT",
"ROP",
"ROSEU",
"ROSS",
"ROST",
"ROVR",
"ROVRW",
"RPAY",
"RPD",
"RPHM",
"RPID",
"RPM",
"RPRX",
"RPT",
"RPTX",
"RQI",
"RRBI",
"RRC",
"RRD",
"RRGB",
"RRR",
"RRX",
"RS",
"RSF",
"RSG",
"RSI",
"RSKD",
"RSLS",
"RSSS",
"RSVR",
"RSVRW",
"RTLR",
"RTX",
"RUBY",
"RUN",
"RUSHA",
"RUSHB",
"RUTH",
"RVAC",
"RVACU",
"RVACW",
"RVI",
"RVLV",
"RVMD",
"RVNC",
"RVP",
"RVPH",
"RVPHW",
"RVSB",
"RVT",
"RWAY",
"RWLK",
"RWT",
"RXDX",
"RXRA",
"RXRAU",
"RXRAW",
"RXRX",
"RXST",
"RXT",
"RY",
"RYAAY",
"RYAM",
"RYAN",
"RYB",
"RYI",
"RYN",
"RYTM",
"RZA",
"RZB",
"RZLT",
"S",
"SA",
"SABR",
"SABRP",
"SABS",
"SABSW",
"SACC",
"SACH",
"SAFE",
"SAFM",
"SAFT",
"SAGE",
"SAH",
"SAIA",
"SAIC",
"SAIL",
"SAK",
"SAL",
"SALM",
"SAM",
"SAMAU",
"SAMG",
"SAN",
"SANA",
"SANBU",
"SAND          ",
"SANM",
"SANW",
"SAP",
"SAR",
"SASR",
"SATS",
"SAVA",
"SAVE",
"SB",
"SBAC",
"SBBA",
"SBCF",
"SBEA",
"SBEAU",
"SBEAW",
"SBET",
"SBEV",
"SBFG",
"SBGI",
"SBH",
"SBI",
"SBII",
"SBLK",
"SBNY",
"SBNYP",
"SBOW",
"SBR",
"SBRA",
"SBS",
"SBSI",
"SBSW",
"SBT",
"SBTX",
"SBUX",
"SC",
"SCAQU",
"SCAQW",
"SCCB",
"SCCC",
"SCCO",
"SCD",
"SCHL",
"SCHN",
"SCHW",
"SCI",
"SCKT",
"SCL",
"SCLE",
"SCLEU",
"SCLEW",
"SCM",
"SCMAU",
"SCOA",
"SCOAU",
"SCOAW",
"SCOB",
"SCOBU",
"SCOBW",
"SCOR",
"SCPH",
"SCPL",
"SCPS",
"SCS",
"SCSC",
"SCU",
"SCVL",
"SCVX",
"SCWX",
"SCX",
"SCYX",
"SD",
"SDAC",
"SDACU",
"SDACW",
"SDC",
"SDGR",
"SDH",
"SDHY",
"SDIG",
"SDPI",
"SE",
"SEAC",
"SEAH",
"SEAS",
"SEAT",
"SEATW",
"SEB",
"SECO",
"SEDG",
"SEE",
"SEED",
"SEEL",
"SEER",
"SEIC",
"SELB",
"SELF",
"SEM",
"SEMR",
"SENEA",
"SENEB",
"SENS",
"SERA",
"SESN",
"SEVN",
"SF",
"SFB",
"SFBC",
"SFBS",
"SFE",
"SFET",
"SFIX",
"SFL",
"SFM",
"SFNC",
"SFST",
"SFT",
"SFUN",
"SGA",
"SGBX",
"SGC",
"SGEN",
"SGFY",
"SGH",
"SGHT",
"SGLB",
"SGLBW",
"SGMA",
"SGML",
"SGMO",
"SGMS",
"SGOC",
"SGRP",
"SGRY",
"SGTX",
"SGU",
"SHAC",
"SHACU",
"SHACW",
"SHAK",
"SHBI",
"SHC",
"SHCAU",
"SHCR",
"SHCRW",
"SHEN",
"SHG",
"SHI",
"SHIP",
"SHIPW",
"SHIPZ",
"SHLS",
"SHLX",
"SHO",
"SHOO",
"SHOP",
"SHPW",
"SHQAU",
"SHQAW",
"SHW",
"SHYF",
"SI",
"SIBN",
"SID",
"SIEB",
"SIEN",
"SIERU",
"SIF",
"SIFY",
"SIG",
"SIGA",
"SIGI",
"SIGIP",
"SII",
"SILC",
"SILK",
"SILV",
"SIM",
"SIMO",
"SINO",
"SINT",
"SIOX",
"SIRI",
"SISI",
"SITC",
"SITE",
"SITM",
"SIVB",
"SIVBP",
"SIX",
"SJ",
"SJI",
"SJIJ",
"SJIV",
"SJM",
"SJR",
"SJT",
"SJW",
"SKE",
"SKIL",
"SKIN",
"SKLZ",
"SKM",
"SKT",
"SKX",
"SKY",
"SKYA",
"SKYAU",
"SKYAW",
"SKYT",
"SKYW",
"SLAB",
"SLAC",
"SLAM",
"SLAMU",
"SLAMW",
"SLB",
"SLCA",
"SLCR",
"SLCRU",
"SLCRW",
"SLDB",
"SLF",
"SLG",
"SLGC",
"SLGCW",
"SLGG",
"SLGL",
"SLGN",
"SLHG",
"SLI",
"SLM",
"SLMBP",
"SLN",
"SLNG",
"SLNH",
"SLNHP",
"SLNO",
"SLP",
"SLQT",
"SLRC",
"SLRX",
"SLS",
"SLVM",
"SLVR",
"SLVRU",
"SLVRW",
"SM",
"SMAPU",
"SMAR",
"SMBC",
"SMBK",
"SMCI",
"SMED",
"SMFG",
"SMFR",
"SMFRW",
"SMG",
"SMHI",
"SMID",
"SMIH",
"SMIHU",
"SMIHW",
"SMIT",
"SMLP",
"SMLR",
"SMM",
"SMMF",
"SMMT",
"SMP",
"SMPL",
"SMRT",
"SMSI",
"SMTC",
"SMTI",
"SMTS",
"SMWB",
"SNA",
"SNAP",
"SNAX",
"SNAXW",
"SNBR",
"SNCE",
"SNCR",
"SNCRL",
"SNCY",
"SND",
"SNDL",
"SNDR",
"SNDX",
"SNES",
"SNEX",
"SNFCA",
"SNGX",
"SNGXW",
"SNII",
"SNMP",
"SNN",
"SNOA",
"SNOW",
"SNP",
"SNPO",
"SNPS",
"SNPX",
"SNRH",
"SNRHU",
"SNRHW",
"SNSE",
"SNT",
"SNTG",
"SNV",
"SNX",
"SNY",
"SO",
"SOFI",
"SOFIW",
"SOHO",
"SOHOB",
"SOHON",
"SOHOO",
"SOHU",
"SOI",
"SOJC",
"SOJD",
"SOJE",
"SOL",
"SOLN",
"SOLO",
"SOLOW",
"SOLY",
"SON",
"SONM",
"SONN",
"SONO",
"SONX",
"SONY",
"SOPH",
"SOR",
"SOS",
"SOTK",
"SOVO",
"SP",
"SPAQ",
"SPB",
"SPCB",
"SPCE",
"SPE",
"SPFI",
"SPG",
"SPGI",
"SPGS",
"SPH",
"SPI",
"SPIR",
"SPK",
"SPKB",
"SPKBU",
"SPKBW",
"SPLK",
"SPLP",
"SPNE",
"SPNS",
"SPNT",
"SPOK",
"SPOT",
"SPPI",
"SPR",
"SPRB",
"SPRO",
"SPSC",
"SPT",
"SPTK",
"SPTKW",
"SPTN",
"SPWH",
"SPWR",
"SPXC",
"SPXX",
"SQ",
"SQFT",
"SQFTP",
"SQL",
"SQLLW",
"SQM",
"SQNS",
"SQSP",
"SQZ",
"SR",
"SRAD",
"SRAX",
"SRC",
"SRCE",
"SRCL",
"SRDX",
"SRE",
"SREA",
"SREV",
"SRG",
"SRGA",
"SRI",
"SRL",
"SRLP",
"SRNE",
"SRPT",
"SRRA",
"SRRK",
"SRSA",
"SRSAW",
"SRT",
"SRTS",
"SRV",
"SRZN",
"SRZNW",
"SSAA",
"SSAAU",
"SSAAW",
"SSB",
"SSBI",
"SSBK",
"SSD",
"SSKN",
"SSL",
"SSNC",
"SSNT",
"SSP",
"SSRM",
"SSSS",
"SSTI",
"SSTK",
"SSY",
"SSYS",
"ST",
"STAA",
"STAB",
"STAF",
"STAG",
"STAR          ",
"STBA",
"STC",
"STCN",
"STE",
"STEM",
"STEP",
"STER",
"STFC",
"STG",
"STGW",
"STIM",
"STK",
"STKL",
"STKS",
"STL",
"STLA",
"STLD",
"STM",
"STN",
"STNE",
"STNG",
"STOK",
"STON",
"STOR",
"STRA",
"STRC",
"STRCW",
"STRE",
"STRL",
"STRM",
"STRO",
"STRR",
"STRRP",
"STRS",
"STRT",
"STSA",
"STT",
"STTK",
"STVN",
"STWD",
"STX",
"STXB",
"STXS",
"STZ",
"SU",
"SUI",
"SUM",
"SUMO",
"SUMR",
"SUN",
"SUNL",
"SUNS",
"SUNW",
"SUP",
"SUPN",
"SUPV",
"SURF",
"SURG",
"SURGW",
"SUZ",
"SV",
"SVC",
"SVFA",
"SVFAU",
"SVFAW",
"SVFB",
"SVFC",
"SVFD",
"SVM",
"SVNAU",
"SVOK",
"SVOKU",
"SVOKW",
"SVRA",
"SVSVU",
"SVSVW",
"SVT",
"SVVC",
"SWAG",
"SWAGU",
"SWAGW",
"SWAV",
"SWBI",
"SWCH",
"SWET",
"SWETU",
"SWETW",
"SWI",
"SWIM",
"SWIR",
"SWK",
"SWKH",
"SWKS",
"SWM",
"SWN",
"SWSS",
"SWSSU",
"SWSSW",
"SWT",
"SWTX",
"SWX",
"SWZ",
"SXC",
"SXI",
"SXT",
"SXTC",
"SY",
"SYBT",
"SYBX",
"SYF",
"SYK",
"SYN",
"SYNA",
"SYNH",
"SYNL",
"SYPR",
"SYRS",
"SYTA",
"SYTAW",
"SYY",
"SZC",
"SZZLU",
"T",
"TA",
"TAC",
"TACA",
"TACO",
"TACT",
"TAIT",
"TAK",
"TAL",
"TALK",
"TALKW",
"TALO",
"TALS",
"TANH",
"TANNI",
"TANNL",
"TANNZ",
"TAOP",
"TAP",
"TARA",
"TARO",
"TARS",
"TASK",
"TAST",
"TATT",
"TAYD",
"TBB",
"TBBK",
"TBC",
"TBCP",
"TBCPU",
"TBCPW",
"TBI",
"TBK",
"TBKCP",
"TBLA",
"TBLAW",
"TBLD",
"TBLT",
"TBLTW",
"TBNK",
"TBPH",
"TBSAW",
"TC",
"TCAC",
"TCACU",
"TCACW",
"TCBC",
"TCBI",
"TCBIO",
"TCBK",
"TCBS",
"TCDA",
"TCFC",
"TCI",
"TCMD",
"TCN",
"TCOM",
"TCON",
"TCPC",
"TCRR",
"TCRX",
"TCS",
"TCVA",
"TCX",
"TD",
"TDC",
"TDCX",
"TDF",
"TDG",
"TDOC",
"TDS",
"TDUP",
"TDW",
"TDY",
"TEAF",
"TEAM",
"TECH",
"TECK",
"TECTP",
"TEDU",
"TEF",
"TEI",
"TEKK",
"TEKKW",
"TEL",
"TELA",
"TELL",
"TEN",
"TENB",
"TENX",
"TEO",
"TER",
"TERN",
"TESS",
"TETC",
"TETCU",
"TETCW",
"TEVA",
"TEX",
"TFC",
"TFFP",
"TFII",
"TFSA",
"TFSL",
"TFX",
"TG",
"TGA",
"TGB",
"TGH",
"TGI",
"TGLS",
"TGNA",
"TGP",
"TGS",
"TGT",
"TGTX",
"TGVCU",
"TH",
"THACU",
"THC",
"THCA",
"THCAW",
"THCP",
"THCPU",
"THCPW",
"THFF",
"THG",
"THM",
"THMA",
"THMAU",
"THMAW",
"THMO",
"THO",
"THQ",
"THR",
"THRM",
"THRN",
"THRX",
"THRY",
"THS",
"THTX",
"THW",
"THWWW",
"TIG",
"TIGO",
"TIGR",
"TIL",
"TILE",
"TIMB",
"TINV",
"TIOA",
"TIOAU",
"TIOAW",
"TIPT",
"TIRX",
"TISI",
"TITN",
"TIXT",
"TJX",
"TK",
"TKAT",
"TKC",
"TKNO",
"TKR",
"TLGA",
"TLIS",
"TLK",
"TLMD",
"TLMDW",
"TLRY",
"TLS",
"TLSA",
"TLYS",
"TM",
"TMAC",
"TMBR",
"TMC",
"TMCI",
"TMCWW",
"TMDI",
"TMDX",
"TME",
"TMHC",
"TMKR",
"TMKRU",
"TMKRW",
"TMO",
"TMP",
"TMPM",
"TMPMW",
"TMQ",
"TMST",
"TMUS",
"TMX",
"TNC",
"TNDM",
"TNET",
"TNGX",
"TNK",
"TNL",
"TNP",
"TNXP",
"TNYA",
"TOACU",
"TOL",
"TOMZ",
"TOPS",
"TOST",
"TOUR",
"TOWN",
"TPB",
"TPBA",
"TPBAU",
"TPBAW",
"TPC",
"TPGS",
"TPGY",
"TPH",
"TPHS",
"TPIC",
"TPL",
"TPR",
"TPST",
"TPTA",
"TPTX",
"TPVG",
"TPX",
"TPZ",
"TR",
"TRC",
"TRCA",
"TRDA",
"TREB",
"TREC",
"TREE",
"TREX",
"TRGP",
"TRHC",
"TRI",
"TRIB",
"TRIL",
"TRIN",
"TRIP",
"TRIT",
"TRITW",
"TRKA",
"TRKAW",
"TRMB",
"TRMD",
"TRMK",
"TRMR",
"TRN",
"TRNO",
"TRNS",
"TRON",
"TRONW",
"TROW",
"TROX",
"TRP",
"TRQ",
"TRS",
"TRST",
"TRT",
"TRTL",
"TRTN",
"TRTX",
"TRU",
"TRUE",
"TRUP",
"TRV",
"TRVG",
"TRVI",
"TRVN",
"TRX",
"TS",
"TSBK",
"TSC",
"TSCAP",
"TSCBP",
"TSCO",
"TSE",
"TSEM",
"TSHA",
"TSI",
"TSIB",
"TSIBU",
"TSIBW",
"TSLA",
"TSLX",
"TSM",
"TSN",
"TSP",
"TSPQ",
"TSQ",
"TSRI",
"TSVT",
"TT",
"TTC",
"TTCF",
"TTD",
"TTE",
"TTEC",
"TTEK",
"TTGT",
"TTI",
"TTM",
"TTMI",
"TTNP",
"TTOO",
"TTP",
"TTSH",
"TTWO",
"TU",
"TUEM",
"TUFN",
"TUGC",
"TUGCU",
"TUGCW",
"TUP",
"TURN",
"TUSK",
"TUYA",
"TV",
"TVAC",
"TVACW",
"TVC",
"TVE",
"TVTX",
"TVTY",
"TW",
"TWCB",
"TWCBU",
"TWCBW",
"TWI",
"TWIN",
"TWKS",
"TWLO",
"TWLV",
"TWLVU",
"TWLVW",
"TWN",
"TWND",
"TWNI",
"TWNK",
"TWNT",
"TWO",
"TWOA",
"TWOU",
"TWST",
"TWTR",
"TX",
"TXG",
"TXMD",
"TXN",
"TXRH",
"TXT",
"TY",
"TYG",
"TYL",
"TYME",
"TYRA",
"TZOO",
"TZPS",
"TZPSU",
"TZPSW",
"U",
"UA",
"UAA",
"UAL",
"UAMY",
"UAN",
"UAVS",
"UBA",
"UBCP",
"UBER",
"UBFO",
"UBOH",
"UBP",
"UBS",
"UBSI",
"UBX",
"UCBI",
"UCBIO",
"UCL",
"UCTT",
"UDMY",
"UDR",
"UE",
"UEC",
"UEIC",
"UEPS",
"UFAB",
"UFCS",
"UFI",
"UFPI",
"UFPT",
"UFS",
"UG",
"UGI",
"UGIC",
"UGP",
"UGRO",
"UHAL",
"UHS",
"UHT",
"UI",
"UIHC",
"UIS",
"UK",
"UKOMW",
"UL",
"ULBI",
"ULCC",
"ULH",
"ULTA",
"UMBF",
"UMC",
"UMH",
"UMPQ",
"UNAM",
"UNB",
"UNCY",
"UNF",
"UNFI",
"UNH",
"UNIT",
"UNM",
"UNMA",
"UNP",
"UNTY",
"UNVR",
"UONE",
"UONEK",
"UP",
"UPC",
"UPH",
"UPLD",
"UPS",
"UPST",
"UPTD",
"UPTDU",
"UPTDW",
"UPWK",
"URBN",
"URG",
"URGN",
"URI",
"UROY",
"USA",
"USAC",
"USAK",
"USAP",
"USAS",
"USAU",
"USB",
"USCB",
"USCTU",
"USDP",
"USEG",
"USFD",
"USIO",
"USLM",
"USM",
"USNA",
"USPH",
"USWS",
"USWSW",
"USX",
"UTF",
"UTG",
"UTHR",
"UTI",
"UTL",
"UTMD",
"UTME",
"UTRS",
"UTSI",
"UTZ",
"UUU",
"UUUU",
"UVE",
"UVSP",
"UVV",
"UWMC",
"UXIN",
"UZD",
"UZE",
"UZF",
"V",
"VABK",
"VAC",
"VACC",
"VAL",
"VALE",
"VALN",
"VALU",
"VAPO",
"VAQC",
"VATE",
"VBF",
"VBFC",
"VBIV",
"VBLT",
"VBNK",
"VBTX",
"VC",
"VCEL",
"VCF",
"VCIF",
"VCKA",
"VCKAU",
"VCKAW",
"VCNX",
"VCRA",
"VCTR",
"VCV",
"VCXA",
"VCXAU",
"VCXAW",
"VCYT",
"VEC",
"VECO",
"VECT",
"VEDL",
"VEEE",
"VEEV",
"VEL",
"VELO",
"VELOU",
"VELOW",
"VENA",
"VENAR",
"VENAU",
"VENAW",
"VEON",
"VERA",
"VERB",
"VERBW",
"VERI",
"VERO",
"VERU",
"VERV",
"VERX",
"VERY",
"VET",
"VEV",
"VFC",
"VFF",
"VFL",
"VG",
"VGFC",
"VGI",
"VGII",
"VGM",
"VGR",
"VGZ",
"VHAQ",
"VHC",
"VHI",
"VIA",
"VIAC",
"VIACA",
"VIACP",
"VIAO",
"VIASP",
"VIAV",
"VICI",
"VICR",
"VIEW",
"VIEWW",
"VII",
"VIIAU",
"VIIAW",
"VINC",
"VINO",
"VINP",
"VIOT",
"VIPS",
"VIR",
"VIRC",
"VIRI",
"VIRT",
"VIRX",
"VISL",
"VIST",
"VITL",
"VIV",
"VIVE",
"VIVO",
"VJET",
"VKI",
"VKQ",
"VKTX",
"VLAT",
"VLATW",
"VLCN",
"VLD",
"VLDR",
"VLDRW",
"VLGEA",
"VLN",
"VLO",
"VLON",
"VLRS",
"VLT",
"VLTA",
"VLY",
"VLYPO",
"VLYPP",
"VMAC",
"VMACW",
"VMAR",
"VMC",
"VMD",
"VMEO",
"VMI",
"VMM",
"VMO",
"VMW",
"VNCE",
"VNDA",
"VNE",
"VNET",
"VNO",
"VNOM",
"VNRX",
"VNT",
"VNTR",
"VOC",
"VOD",
"VOLT",
"VOR",
"VOSO",
"VOSOU",
"VOSOW",
"VOXX",
"VOYA",
"VPCB",
"VPCBU",
"VPCBW",
"VPCC",
"VPG",
"VPV",
"VQS",
"VRA",
"VRAR",
"VRAY",
"VRCA",
"VRDN",
"VREX",
"VRM",
"VRME",
"VRMEW",
"VRNA",
"VRNS",
"VRNT",
"VRPX",
"VRRM",
"VRS",
"VRSK",
"VRSN",
"VRT",
"VRTS",
"VRTV",
"VRTX",
"VS",
"VSACU",
"VSAT",
"VSCO",
"VSEC",
"VSH",
"VSSYW",
"VST",
"VSTA",
"VSTM",
"VSTO",
"VTAQ",
"VTAQR",
"VTAQU",
"VTAQW",
"VTEX",
"VTGN",
"VTIQ",
"VTIQU",
"VTIQW",
"VTN",
"VTNR",
"VTOL",
"VTR",
"VTRS",
"VTRU",
"VTSI",
"VTVT",
"VTYX",
"VUZI",
"VVI",
"VVNT",
"VVOS",
"VVPR",
"VVR",
"VVV",
"VWE",
"VWTR",
"VXRT",
"VYGG",
"VYGR",
"VYNE",
"VYNT",
"VZ",
"VZIO",
"W",
"WAB",
"WABC",
"WAFD",
"WAFDP",
"WAFU",
"WAL",
"WALA",
"WALD",
"WALDU",
"WALDW",
"WARR",
"WASH",
"WAT",
"WATT",
"WAVC",
"WAVE",
"WB",
"WBA",
"WBK",
"WBS",
"WBT",
"WBX",
"WCC",
"WCN",
"WD",
"WDAY",
"WDC",
"WDFC",
"WDH",
"WDI",
"WE",
"WEA",
"WEBR",
"WEC",
"WEI",
"WELL",
"WEN",
"WERN",
"WES",
"WETF",
"WEX",
"WEYS",
"WF",
"WFC",
"WFCF",
"WFG",
"WFRD",
"WGO",
"WH",
"WHD",
"WHF",
"WHFBZ",
"WHG",
"WHLM",
"WHLR",
"WHLRD",
"WHLRP",
"WHR",
"WIA",
"WILC",
"WIMI",
"WINA",
"WING",
"WINT",
"WINV",
"WINVR",
"WINVW",
"WIRE",
"WISA",
"WISH",
"WIT",
"WIW",
"WIX",
"WK",
"WKEY",
"WKHS",
"WKME",
"WKSP",
"WKSPW",
"WLDN",
"WLFC",
"WLK",
"WLKP",
"WLL",
"WLMS",
"WLTW",
"WM",
"WMB",
"WMC",
"WMG",
"WMK",
"WMPN",
"WMS",
"WMT",
"WNC",
"WNEB",
"WNS",
"WNW",
"WOLF",
"WOOF",
"WOR",
"WORX",
"WOW",
"WPC",
"WPCA",
"WPM",
"WPP",
"WPRT",
"WQGA",
"WRAC",
"WRAP",
"WRB",
"WRBY",
"WRE",
"WRK",
"WRLD",
"WRN",
"WSBC",
"WSBCP",
"WSBF",
"WSC",
"WSFS",
"WSM",
"WSO",
"WSR",
"WST",
"WSTG",
"WTBA",
"WTER",
"WTFC",
"WTFCM",
"WTFCP",
"WTI",
"WTM",
"WTRG",
"WTRH",
"WTRU",
"WTS",
"WTT",
"WTTR",
"WU",
"WVE",
"WVFC",
"WVVI",
"WVVIP",
"WW",
"WWACU",
"WWD",
"WWE",
"WWR",
"WWW",
"WY",
"WYNN",
"WYY",
"X",
"XAIR",
"XBIO",
"XBIT",
"XCUR",
"XEL",
"XELA",
"XELB",
"XENE",
"XENT",
"XERS",
"XFINU",
"XFLT",
"XFOR",
"XGN",
"XHR",
"XIN",
"XL",
"XLNX",
"XLO",
"XLRN",
"XM",
"XMTR",
"XNCR",
"XNET",
"XOM",
"XOMA",
"XOMAO",
"XOMAP",
"XONE",
"XOS",
"XOSWW",
"XP",
"XPAX",
"XPAXW",
"XPDI",
"XPDIU",
"XPDIW",
"XPEL",
"XPER",
"XPEV",
"XPL",
"XPO",
"XPOA",
"XPOF",
"XPRO",
"XRAY",
"XRTX",
"XRX",
"XSPA",
"XTLB",
"XTNT",
"XXII",
"XYF",
"XYL",
"Y",
"YAC",
"YALA",
"YCBD",
"YELL",
"YELP",
"YETI",
"YEXT",
"YGMZ",
"YI",
"YJ",
"YMAB",
"YMM",
"YMTX",
"YNDX",
"YORW",
"YOU",
"YPF",
"YQ",
"YRD",
"YSAC",
"YSACU",
"YSACW",
"YSG",
"YTEN",
"YTPG",
"YTRA",
"YUM",
"YUMC",
"YVR",
"YY",
"Z",
"ZBH",
"ZBRA",
"ZCMD",
"ZD",
"ZDGE",
"ZEAL",
"ZEN",
"ZENV",
"ZEPP",
"ZEST",
"ZETA",
"ZEUS",
"ZEV",
"ZG",
"ZGNX",
"ZGYH",
"ZGYHR",
"ZGYHU",
"ZGYHW",
"ZH",
"ZI",
"ZIM",
"ZION",
"ZIONL",
"ZIONO",
"ZIONP",
"ZIOP",
"ZIP",
"ZIVO",
"ZIVOW",
"ZIXI",
"ZKIN",
"ZLAB",
"ZM",
"ZME",
"ZNGA",
"ZNH",
"ZNTE",
"ZNTEU",
"ZNTEW",
"ZNTL",
"ZOM",
"ZS",
"ZSAN",
"ZT",
"ZTAQU",
"ZTAQW",
"ZTO",
"ZTR",
"ZTS",
"ZUMZ",
"ZUO",
"ZVIA",
"ZVO",
"ZWRK",
"ZWRKU",
"ZWRKW",
"ZWS",
"ZY",
"ZYME",
"ZYNE",
"ZYXI"
]
